Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AccountDefenderAssessmentAccountTakeoverVerdict

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Account takeover risk assessment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1AccountDefenderAssessmentAccountTakeoverVerdict

Returns a new instance of GoogleCloudRecaptchaenterpriseV1AccountDefenderAssessmentAccountTakeoverVerdict.



93
94
95
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 93

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#riskFloat

Output only. Account takeover attempt probability. Values are from 0.0 (lowest risk) to 1.0 (highest risk). Corresponds to the JSON property risk

Returns:

  • (Float)


77
78
79
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 77

def risk
  @risk
end

#risk_reasonsArray<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AccountDefenderAssessmentAccountRiskReason>

Output only. Unordered list. Reasons why the request appears risky. Risk reasons can be returned even if the risk is low, as trustworthy requests can still have some risk signals. Corresponds to the JSON property riskReasons



84
85
86
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 84

def risk_reasons
  @risk_reasons
end

#trust_reasonsArray<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AccountDefenderAssessmentAccountTrustReason>

Output only. Unordered list. Reasons why the request appears trustworthy. Trust reasons can be returned even if the risk is high, as risky requests can still have some trust signals. Corresponds to the JSON property trustReasons



91
92
93
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 91

def trust_reasons
  @trust_reasons
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



98
99
100
101
102
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 98

def update!(**args)
  @risk = args[:risk] if args.key?(:risk)
  @risk_reasons = args[:risk_reasons] if args.key?(:risk_reasons)
  @trust_reasons = args[:trust_reasons] if args.key?(:trust_reasons)
end