Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AndroidKeySettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Settings specific to keys that can be used by Android apps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1AndroidKeySettings

Returns a new instance of GoogleCloudRecaptchaenterpriseV1AndroidKeySettings.



222
223
224
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 222

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_all_package_namesBoolean Also known as: allow_all_package_names?

Optional. If set to true, allowed_package_names are not enforced. Corresponds to the JSON property allowAllPackageNames

Returns:

  • (Boolean)


202
203
204
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 202

def allow_all_package_names
  @allow_all_package_names
end

#allowed_package_namesArray<String>

Optional. Android package names of apps allowed to use the key. Example: 'com. companyname.appname' Each key supports a maximum of 250 package names. To use a key on more apps, set allow_all_package_names to true. When this is set, you are responsible for validating the package name by checking the token_properties.android_package_name field in each assessment response against your list of allowed package names. Corresponds to the JSON property allowedPackageNames

Returns:

  • (Array<String>)


213
214
215
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 213

def allowed_package_names
  @allowed_package_names
end

#support_non_google_app_store_distributionBoolean Also known as: support_non_google_app_store_distribution?

Optional. Set to true for keys that are used in an Android application that is available for download in app stores in addition to the Google Play Store. Corresponds to the JSON property supportNonGoogleAppStoreDistribution

Returns:

  • (Boolean)


219
220
221
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 219

def support_non_google_app_store_distribution
  @support_non_google_app_store_distribution
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



227
228
229
230
231
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 227

def update!(**args)
  @allow_all_package_names = args[:allow_all_package_names] if args.key?(:allow_all_package_names)
  @allowed_package_names = args[:allowed_package_names] if args.key?(:allowed_package_names)
  @support_non_google_app_store_distribution = args[:support_non_google_app_store_distribution] if args.key?(:support_non_google_app_store_distribution)
end