Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ChallengeRuleGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

A collection of challenge rules that applies to one or more actions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1ChallengeRuleGroup

Returns a new instance of GoogleCloudRecaptchaenterpriseV1ChallengeRuleGroup.



627
628
629
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 627

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsArray<String>

Required. Action name provided at token generation. The action name is not case-sensitive and can only contain alphanumeric characters, slashes, and underscores. If "*" is provided, the rule group applies to all actions. If multiple actions are provided, the rule group is applied to all of them. This field is required. Corresponds to the JSON property actions

Returns:

  • (Array<String>)


618
619
620
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 618

def actions
  @actions
end

#challenge_rulesArray<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ChallengeRule>

Required. A list of rules that configure when and how reCAPTCHA presents a challenge. reCAPTCHA evaluates these rules in order and applies the first one that matches. Corresponds to the JSON property challengeRules



625
626
627
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 625

def challenge_rules
  @challenge_rules
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



632
633
634
635
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 632

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @challenge_rules = args[:challenge_rules] if args.key?(:challenge_rules)
end