Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ClientSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Configuration for clients to protect with reCAPTCHA.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1ClientSettings

Returns a new instance of GoogleCloudRecaptchaenterpriseV1ClientSettings.



674
675
676
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 674

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_all_domainsBoolean Also known as: allow_all_domains?

Optional. If set to true, it means allowed_domains are not enforced. Corresponds to the JSON property allowAllDomains

Returns:

  • (Boolean)


654
655
656
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 654

def allow_all_domains
  @allow_all_domains
end

#allowed_domainsArray<String>

Optional. Domains or subdomains of websites allowed to use the policy. All subdomains of an allowed domain are automatically allowed. A valid domain requires a host and must not include any path, port, query or fragment. Examples: 'example.com' or 'subdomain.example.com' Each policy supports a maximum of 250 domains. To use a policy on more domains, set allow_all_domains to true. When this is set, you are responsible for validating the hostname by checking the token_properties.hostname field in each assessment response against your list of allowed domains. Corresponds to the JSON property allowedDomains

Returns:

  • (Array<String>)


667
668
669
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 667

def allowed_domains
  @allowed_domains
end

#protected_endpoint_groupGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ProtectedEndpointGroup

Configuration for API endpoints to protect with reCAPTCHA. Corresponds to the JSON property protectedEndpointGroup



672
673
674
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 672

def protected_endpoint_group
  @protected_endpoint_group
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



679
680
681
682
683
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 679

def update!(**args)
  @allow_all_domains = args[:allow_all_domains] if args.key?(:allow_all_domains)
  @allowed_domains = args[:allowed_domains] if args.key?(:allowed_domains)
  @protected_endpoint_group = args[:protected_endpoint_group] if args.key?(:protected_endpoint_group)
end