Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Event

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

The event being assessed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1Event

Returns a new instance of GoogleCloudRecaptchaenterpriseV1Event.



668
669
670
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expected_actionString

Optional. The expected action for this type of event. This should be the same action provided at token generation time on client-side platforms already integrated with recaptcha enterprise. Corresponds to the JSON property expectedAction

Returns:

  • (String)


574
575
576
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 574

def expected_action
  @expected_action
end

#expressBoolean Also known as: express?

Optional. Flag for a reCAPTCHA express request for an assessment without a token. If enabled, site_key must reference an Express site key. Corresponds to the JSON property express

Returns:

  • (Boolean)


580
581
582
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 580

def express
  @express
end

#firewall_policy_evaluationBoolean Also known as: firewall_policy_evaluation?

Optional. Flag for enabling firewall policy config assessment. If this flag is enabled, the firewall policy is evaluated and a suggested firewall action is returned in the response. Corresponds to the JSON property firewallPolicyEvaluation

Returns:

  • (Boolean)


588
589
590
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 588

def firewall_policy_evaluation
  @firewall_policy_evaluation
end

#fraud_preventionString

Optional. The Fraud Prevention setting for this assessment. Corresponds to the JSON property fraudPrevention

Returns:

  • (String)


594
595
596
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 594

def fraud_prevention
  @fraud_prevention
end

#hashed_account_idString

Optional. Deprecated: use user_info.account_id instead. Unique stable hashed user identifier for the request. The identifier must be hashed using hmac- sha256 with stable secret. Corresponds to the JSON property hashedAccountId NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


602
603
604
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 602

def 
  @hashed_account_id
end

#headersArray<String>

Optional. HTTP header information about the request. Corresponds to the JSON property headers

Returns:

  • (Array<String>)


607
608
609
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 607

def headers
  @headers
end

#ja3String

Optional. JA3 fingerprint for SSL clients. To learn how to compute this fingerprint, please refer to https://github.com/salesforce/ja3. Corresponds to the JSON property ja3

Returns:

  • (String)


613
614
615
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 613

def ja3
  @ja3
end

#ja4String

Optional. JA4 fingerprint for SSL clients. To learn how to compute this fingerprint, please refer to https://github.com/FoxIO-LLC/ja4. Corresponds to the JSON property ja4

Returns:

  • (String)


619
620
621
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 619

def ja4
  @ja4
end

#requested_uriString

Optional. The URI resource the user requested that triggered an assessment. Corresponds to the JSON property requestedUri

Returns:

  • (String)


624
625
626
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 624

def requested_uri
  @requested_uri
end

#site_keyString

Optional. The site key that was used to invoke reCAPTCHA Enterprise on your site and generate the token. Corresponds to the JSON property siteKey

Returns:

  • (String)


630
631
632
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 630

def site_key
  @site_key
end

#tokenString

Optional. The user response token provided by the reCAPTCHA Enterprise client- side integration on your site. Corresponds to the JSON property token

Returns:

  • (String)


636
637
638
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 636

def token
  @token
end

#transaction_dataGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionData

Transaction data associated with a payment protected by reCAPTCHA Enterprise. Corresponds to the JSON property transactionData



641
642
643
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 641

def transaction_data
  @transaction_data
end

#user_agentString

Optional. The user agent present in the request from the user's device related to this event. Corresponds to the JSON property userAgent

Returns:

  • (String)


647
648
649
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 647

def user_agent
  @user_agent
end

#user_infoGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1UserInfo

User information associated with a request protected by reCAPTCHA Enterprise. Corresponds to the JSON property userInfo



652
653
654
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 652

def 
  @user_info
end

#user_ip_addressString

Optional. The IP address in the request from the user's device related to this event. Corresponds to the JSON property userIpAddress

Returns:

  • (String)


658
659
660
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 658

def user_ip_address
  @user_ip_address
end

#waf_token_assessmentBoolean Also known as: waf_token_assessment?

Optional. Flag for running Web Application Firewall (WAF) token assessment. If enabled, the token must be specified, and have been created by a WAF-enabled key. Corresponds to the JSON property wafTokenAssessment

Returns:

  • (Boolean)


665
666
667
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 665

def waf_token_assessment
  @waf_token_assessment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 673

def update!(**args)
  @expected_action = args[:expected_action] if args.key?(:expected_action)
  @express = args[:express] if args.key?(:express)
  @firewall_policy_evaluation = args[:firewall_policy_evaluation] if args.key?(:firewall_policy_evaluation)
  @fraud_prevention = args[:fraud_prevention] if args.key?(:fraud_prevention)
  @hashed_account_id = args[:hashed_account_id] if args.key?(:hashed_account_id)
  @headers = args[:headers] if args.key?(:headers)
  @ja3 = args[:ja3] if args.key?(:ja3)
  @ja4 = args[:ja4] if args.key?(:ja4)
  @requested_uri = args[:requested_uri] if args.key?(:requested_uri)
  @site_key = args[:site_key] if args.key?(:site_key)
  @token = args[:token] if args.key?(:token)
  @transaction_data = args[:transaction_data] if args.key?(:transaction_data)
  @user_agent = args[:user_agent] if args.key?(:user_agent)
  @user_info = args[:user_info] if args.key?(:user_info)
  @user_ip_address = args[:user_ip_address] if args.key?(:user_ip_address)
  @waf_token_assessment = args[:waf_token_assessment] if args.key?(:waf_token_assessment)
end