Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

A FirewallPolicy represents a single matching pattern and resulting actions to take.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FirewallPolicy

Returns a new instance of GoogleCloudRecaptchaenterpriseV1FirewallPolicy.



1078
1079
1080
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsArray<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallAction>

Optional. The actions that the caller should take regarding user access. There should be at most one terminal action. A terminal action is any action that forces a response, such as AllowAction, BlockAction or SubstituteAction. Zero or more non-terminal actions such as SetHeader might be specified. A single policy can contain up to 16 actions. Corresponds to the JSON property actions



1045
1046
1047
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1045

def actions
  @actions
end

#conditionString

Optional. A CEL (Common Expression Language) conditional expression that specifies if this policy applies to an incoming user request. If this condition evaluates to true and the requested path matched the path pattern, the associated actions should be executed by the caller. The condition string is checked for CEL syntax correctness on creation. For more information, see the CEL spec and its language definition. A condition has a max length of 500 characters. Corresponds to the JSON property condition

Returns:

  • (String)


1057
1058
1059
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1057

def condition
  @condition
end

#descriptionString

Optional. A description of what this policy aims to achieve, for convenience purposes. The description can at most include 256 UTF-8 characters. Corresponds to the JSON property description

Returns:

  • (String)


1063
1064
1065
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1063

def description
  @description
end

#nameString

Identifier. The resource name for the FirewallPolicy in the format projects/ project/firewallpolicies/firewallpolicy`. Corresponds to the JSON propertyname`

Returns:

  • (String)


1069
1070
1071
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1069

def name
  @name
end

#pathString

Optional. The path for which this policy applies, specified as a glob pattern. For more information on glob, see the manual page. A path has a max length of 200 characters. Corresponds to the JSON property path

Returns:

  • (String)


1076
1077
1078
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1076

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1083
1084
1085
1086
1087
1088
1089
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1083

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @condition = args[:condition] if args.key?(:condition)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @path = args[:path] if args.key?(:path)
end