Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentStolenInstrumentVerdict

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Information about stolen instrument fraud, where the user is not the legitimate owner of the instrument being used for the purchase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentStolenInstrumentVerdict

Returns a new instance of GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentStolenInstrumentVerdict.



1242
1243
1244
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1242

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#riskFloat

Output only. Probability of this transaction being executed with a stolen instrument. Values are from 0.0 (lowest) to 1.0 (highest). Corresponds to the JSON property risk

Returns:

  • (Float)


1240
1241
1242
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1240

def risk
  @risk
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1247
1248
1249
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1247

def update!(**args)
  @risk = args[:risk] if args.key?(:risk)
end