Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudSignals

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Fraud signals describing users and cards involved in the transaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FraudSignals

Returns a new instance of GoogleCloudRecaptchaenterpriseV1FraudSignals.



1266
1267
1268
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#card_signalsGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudSignalsCardSignals

Signals describing the payment card used in this transaction. Corresponds to the JSON property cardSignals



1259
1260
1261
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1259

def card_signals
  @card_signals
end

#user_signalsGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals

Signals describing the user involved in this transaction. Corresponds to the JSON property userSignals



1264
1265
1266
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1264

def user_signals
  @user_signals
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1271
1272
1273
1274
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1271

def update!(**args)
  @card_signals = args[:card_signals] if args.key?(:card_signals)
  @user_signals = args[:user_signals] if args.key?(:user_signals)
end