Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Signals describing the user involved in this transaction.
Instance Attribute Summary collapse
-
#active_days_lower_bound ⇒ Fixnum
Output only.
-
#synthetic_risk ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals
Returns a new instance of GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals.
1309 1310 1311 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1309 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_days_lower_bound ⇒ Fixnum
Output only. This user (based on email, phone, and other identifiers) has been
seen on the internet for at least this number of days.
Corresponds to the JSON property activeDaysLowerBound
1300 1301 1302 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1300 def active_days_lower_bound @active_days_lower_bound end |
#synthetic_risk ⇒ Float
Output only. Likelihood (from 0.0 to 1.0) this user includes synthetic
components in their identity, such as a randomly generated email address,
temporary phone number, or fake shipping address.
Corresponds to the JSON property syntheticRisk
1307 1308 1309 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1307 def synthetic_risk @synthetic_risk end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1314 1315 1316 1317 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1314 def update!(**args) @active_days_lower_bound = args[:active_days_lower_bound] if args.key?(:active_days_lower_bound) @synthetic_risk = args[:synthetic_risk] if args.key?(:synthetic_risk) end |