Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Metrics
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Metrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Metrics for a single Key.
Instance Attribute Summary collapse
-
#challenge_metrics ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ChallengeMetrics>
Metrics are continuous and in order by dates, and in the granularity of day.
-
#name ⇒ String
Output only.
-
#score_metrics ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ScoreMetrics>
Metrics are continuous and in order by dates, and in the granularity of day.
-
#start_time ⇒ String
Inclusive start time aligned to a day in the America/Los_Angeles (Pacific) timezone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1Metrics
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1Metrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1Metrics
Returns a new instance of GoogleCloudRecaptchaenterpriseV1Metrics.
1454 1455 1456 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1454 def initialize(**args) update!(**args) end |
Instance Attribute Details
#challenge_metrics ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ChallengeMetrics>
Metrics are continuous and in order by dates, and in the granularity of day.
Only challenge-based keys (CHECKBOX, INVISIBLE) have challenge-based data.
Corresponds to the JSON property challengeMetrics
1434 1435 1436 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1434 def challenge_metrics @challenge_metrics end |
#name ⇒ String
Output only. Identifier. The name of the metrics, in the format projects/
project/keys/key/metrics.
Corresponds to the JSON property name
1440 1441 1442 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1440 def name @name end |
#score_metrics ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ScoreMetrics>
Metrics are continuous and in order by dates, and in the granularity of day.
All Key types should have score-based data.
Corresponds to the JSON property scoreMetrics
1446 1447 1448 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1446 def score_metrics @score_metrics end |
#start_time ⇒ String
Inclusive start time aligned to a day in the America/Los_Angeles (Pacific)
timezone.
Corresponds to the JSON property startTime
1452 1453 1454 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1452 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1459 1460 1461 1462 1463 1464 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1459 def update!(**args) @challenge_metrics = args[:challenge_metrics] if args.key?(:challenge_metrics) @name = args[:name] if args.key?(:name) @score_metrics = args[:score_metrics] if args.key?(:score_metrics) @start_time = args[:start_time] if args.key?(:start_time) end |