Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1MigrateKeyRequest
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1MigrateKeyRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
The migrate key request message.
Instance Attribute Summary collapse
-
#skip_billing_check ⇒ Boolean
(also: #skip_billing_check?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1MigrateKeyRequest
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1MigrateKeyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1MigrateKeyRequest
Returns a new instance of GoogleCloudRecaptchaenterpriseV1MigrateKeyRequest.
1403 1404 1405 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1403 def initialize(**args) update!(**args) end |
Instance Attribute Details
#skip_billing_check ⇒ Boolean Also known as: skip_billing_check?
Optional. If true, skips the billing check. A reCAPTCHA Enterprise key or
migrated key behaves differently than a reCAPTCHA (non-Enterprise version) key
when you reach a quota limit (see https://docs.cloud.google.com/recaptcha/
quotas#quota_limit). To avoid any disruption of your usage, we check that a
billing account is present. If your usage of reCAPTCHA is under the free quota,
you can safely skip the billing check and proceed with the migration. See
https://cloud.google.com/recaptcha/docs/billing-information.
Corresponds to the JSON property skipBillingCheck
1400 1401 1402 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1400 def skip_billing_check @skip_billing_check end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1408 1409 1410 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1408 def update!(**args) @skip_billing_check = args[:skip_billing_check] if args.key?(:skip_billing_check) end |