Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Policy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

A complete configuration set containing multiple grouped rules defining the behavior of reCAPTCHA for fraud detection and prevention.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1Policy

Returns a new instance of GoogleCloudRecaptchaenterpriseV1Policy.



1734
1735
1736
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1734

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#challenge_rule_groupsArray<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ChallengeRuleGroup>

Optional. Rules to configure the behavior of reCAPTCHA for showing a challenge. Rule groups are evaluated in order. Evaluation stops when the first matching rule group is found. Corresponds to the JSON property challengeRuleGroups



1721
1722
1723
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1721

def challenge_rule_groups
  @challenge_rule_groups
end

#client_settingsGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ClientSettings

Configuration for clients to protect with reCAPTCHA. Corresponds to the JSON property clientSettings



1726
1727
1728
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1726

def client_settings
  @client_settings
end

#nameString

Identifier. Resource name for this policy. Format: "projects/project/keys/ key/policy" for a policy under a key. Corresponds to the JSON property name

Returns:

  • (String)


1732
1733
1734
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1732

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1739
1740
1741
1742
1743
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1739

def update!(**args)
  @challenge_rule_groups = args[:challenge_rule_groups] if args.key?(:challenge_rule_groups)
  @client_settings = args[:client_settings] if args.key?(:client_settings)
  @name = args[:name] if args.key?(:name)
end