Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Transaction data associated with a payment protected by reCAPTCHA Enterprise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TransactionData

Returns a new instance of GoogleCloudRecaptchaenterpriseV1TransactionData.



2391
2392
2393
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2391

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billing_addressGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress

Structured address format for billing and shipping addresses. Corresponds to the JSON property billingAddress



2321
2322
2323
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2321

def billing_address
  @billing_address
end

#card_binString

Optional. The Bank Identification Number - generally the first 6 or 8 digits of the card. Corresponds to the JSON property cardBin

Returns:

  • (String)


2327
2328
2329
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2327

def card_bin
  @card_bin
end

#card_last_fourString

Optional. The last four digits of the card. Corresponds to the JSON property cardLastFour

Returns:

  • (String)


2332
2333
2334
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2332

def card_last_four
  @card_last_four
end

#currency_codeString

Optional. The currency code in ISO-4217 format. Corresponds to the JSON property currencyCode

Returns:

  • (String)


2337
2338
2339
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2337

def currency_code
  @currency_code
end

#gateway_infoGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataGatewayInfo

Details about the transaction from the gateway. Corresponds to the JSON property gatewayInfo



2342
2343
2344
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2342

def gateway_info
  @gateway_info
end

#itemsArray<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataItem>

Optional. Items purchased in this transaction. Corresponds to the JSON property items



2347
2348
2349
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2347

def items
  @items
end

#merchantsArray<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataUser>

Optional. Information about the user or users fulfilling the transaction. Corresponds to the JSON property merchants



2352
2353
2354
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2352

def merchants
  @merchants
end

#payment_methodString

Optional. The payment method for the transaction. The allowed values are: * credit-card * debit-card * gift-card * processor-name (If a third-party is used, for example, processor-paypal) * custom-name (If an alternative method is used, for example, custom-crypto) Corresponds to the JSON property paymentMethod

Returns:

  • (String)


2360
2361
2362
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2360

def payment_method
  @payment_method
end

#shipping_addressGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress

Structured address format for billing and shipping addresses. Corresponds to the JSON property shippingAddress



2365
2366
2367
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2365

def shipping_address
  @shipping_address
end

#shipping_valueFloat

Optional. The value of shipping in the specified currency. 0 for free or no shipping. Corresponds to the JSON property shippingValue

Returns:

  • (Float)


2371
2372
2373
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2371

def shipping_value
  @shipping_value
end

#transaction_idString

Unique identifier for the transaction. This custom identifier can be used to reference this transaction in the future, for example, labeling a refund or chargeback event. Two attempts at the same transaction should use the same transaction id. Corresponds to the JSON property transactionId

Returns:

  • (String)


2379
2380
2381
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2379

def transaction_id
  @transaction_id
end

#userGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataUser

Details about a user's account involved in the transaction. Corresponds to the JSON property user



2384
2385
2386
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2384

def user
  @user
end

#valueFloat

Optional. The decimal value of the transaction in the specified currency. Corresponds to the JSON property value

Returns:

  • (Float)


2389
2390
2391
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2389

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2396

def update!(**args)
  @billing_address = args[:billing_address] if args.key?(:billing_address)
  @card_bin = args[:card_bin] if args.key?(:card_bin)
  @card_last_four = args[:card_last_four] if args.key?(:card_last_four)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @gateway_info = args[:gateway_info] if args.key?(:gateway_info)
  @items = args[:items] if args.key?(:items)
  @merchants = args[:merchants] if args.key?(:merchants)
  @payment_method = args[:payment_method] if args.key?(:payment_method)
  @shipping_address = args[:shipping_address] if args.key?(:shipping_address)
  @shipping_value = args[:shipping_value] if args.key?(:shipping_value)
  @transaction_id = args[:transaction_id] if args.key?(:transaction_id)
  @user = args[:user] if args.key?(:user)
  @value = args[:value] if args.key?(:value)
end