Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1UserId

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

An identifier associated with a user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1UserId

Returns a new instance of GoogleCloudRecaptchaenterpriseV1UserId.



2368
2369
2370
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2368

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emailString

Optional. An email address. Corresponds to the JSON property email

Returns:

  • (String)


2354
2355
2356
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2354

def email
  @email
end

#phone_numberString

Optional. A phone number. Should use the E.164 format. Corresponds to the JSON property phoneNumber

Returns:

  • (String)


2359
2360
2361
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2359

def phone_number
  @phone_number
end

#usernameString

Optional. A unique username, if different from all the other identifiers and account_id that are provided. Can be a unique login handle or display name for a user. Corresponds to the JSON property username

Returns:

  • (String)


2366
2367
2368
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2366

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2373
2374
2375
2376
2377
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2373

def update!(**args)
  @email = args[:email] if args.key?(:email)
  @phone_number = args[:phone_number] if args.key?(:phone_number)
  @username = args[:username] if args.key?(:username)
end