Class: Google::Apis::RecaptchaenterpriseV1::RecaptchaEnterpriseService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::RecaptchaenterpriseV1::RecaptchaEnterpriseService
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/service.rb
Overview
reCAPTCHA Enterprise API
Help protect your website from fraudulent activity, spam, and abuse without creating friction.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://recaptchaenterprise.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#add_project_key_ip_override(name, google_cloud_recaptchaenterprise_v1_add_ip_override_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AddIpOverrideResponse
Adds an IP override to a key.
-
#annotate_project_assessment(name, google_cloud_recaptchaenterprise_v1_annotate_assessment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentResponse
Annotates a previously created Assessment to provide additional information on whether the event turned out to be authentic or fraudulent.
-
#create_project_assessment(parent, google_cloud_recaptchaenterprise_v1_assessment_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Assessment
Creates an Assessment of the likelihood an event is legitimate.
-
#create_project_firewallpolicy(parent, google_cloud_recaptchaenterprise_v1_firewall_policy_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy
Creates a new FirewallPolicy, specifying conditions at which reCAPTCHA Enterprise actions can be executed.
-
#create_project_key(parent, google_cloud_recaptchaenterprise_v1_key_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key
Creates a new reCAPTCHA Enterprise key.
-
#delete_project_firewallpolicy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleProtobufEmpty
Deletes the specified firewall policy.
-
#delete_project_key(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleProtobufEmpty
Deletes the specified key.
-
#get_project_firewallpolicy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy
Returns the specified firewall policy.
-
#get_project_key(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key
Returns the specified key.
-
#get_project_key_metrics(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Metrics
Get some aggregated metrics for a Key.
-
#get_project_key_policy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Policy
Get the policy for a key.
-
#initialize ⇒ RecaptchaEnterpriseService
constructor
A new instance of RecaptchaEnterpriseService.
-
#list_project_firewallpolicies(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListFirewallPoliciesResponse
Returns the list of all firewall policies that belong to a project.
-
#list_project_key_ip_overrides(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListIpOverridesResponse
Lists all IP overrides for a key.
-
#list_project_keys(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListKeysResponse
Returns the list of all keys that belong to a project.
-
#list_project_relatedaccountgroup_memberships(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupMembershipsResponse
Get memberships in a group of related accounts.
-
#list_project_relatedaccountgroups(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupsResponse
List groups of related accounts.
-
#migrate_project_key(name, google_cloud_recaptchaenterprise_v1_migrate_key_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key
Migrates an existing key from reCAPTCHA to reCAPTCHA Enterprise.
-
#patch_project_firewallpolicy(name, google_cloud_recaptchaenterprise_v1_firewall_policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy
Updates the specified firewall policy.
-
#patch_project_key(name, google_cloud_recaptchaenterprise_v1_key_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key
Updates the specified key.
-
#remove_project_key_ip_override(name, google_cloud_recaptchaenterprise_v1_remove_ip_override_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1RemoveIpOverrideResponse
Removes an IP override from a key.
-
#reorder_project_firewallpolicy(parent, google_cloud_recaptchaenterprise_v1_reorder_firewall_policies_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ReorderFirewallPoliciesResponse
Reorders all firewall policies.
-
#retrieve_project_key_legacy_secret_key(key, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponse
Returns the secret key related to the specified public key.
-
#search_project_relatedaccountgroupmemberships(project, google_cloud_recaptchaenterprise_v1_search_related_account_group_memberships_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsResponse
Search group memberships related to a given account.
-
#update_project_key_policy(name, google_cloud_recaptchaenterprise_v1_policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Policy
Updates the policy for a key.
Constructor Details
#initialize ⇒ RecaptchaEnterpriseService
Returns a new instance of RecaptchaEnterpriseService.
48 49 50 51 52 53 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-recaptchaenterprise_v1', client_version: Google::Apis::RecaptchaenterpriseV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#add_project_key_ip_override(name, google_cloud_recaptchaenterprise_v1_add_ip_override_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AddIpOverrideResponse
Adds an IP override to a key. The following restrictions hold: * The maximum number of IP overrides per key is 1000. * For any conflict (such as IP already exists or IP part of an existing IP range), an error is returned.
357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 357 def add_project_key_ip_override(name, google_cloud_recaptchaenterprise_v1_add_ip_override_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:addIpOverride', ) command.request_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AddIpOverrideRequest::Representation command.request_object = google_cloud_recaptchaenterprise_v1_add_ip_override_request_object command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AddIpOverrideResponse::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AddIpOverrideResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#annotate_project_assessment(name, google_cloud_recaptchaenterprise_v1_annotate_assessment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentResponse
Annotates a previously created Assessment to provide additional information on whether the event turned out to be authentic or fraudulent.
78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 78 def annotate_project_assessment(name, google_cloud_recaptchaenterprise_v1_annotate_assessment_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:annotate', ) command.request_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentRequest::Representation command.request_object = google_cloud_recaptchaenterprise_v1_annotate_assessment_request_object command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentResponse::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_assessment(parent, google_cloud_recaptchaenterprise_v1_assessment_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Assessment
Creates an Assessment of the likelihood an event is legitimate.
112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 112 def create_project_assessment(parent, google_cloud_recaptchaenterprise_v1_assessment_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/assessments', ) command.request_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Assessment::Representation command.request_object = google_cloud_recaptchaenterprise_v1_assessment_object command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Assessment::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Assessment command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_firewallpolicy(parent, google_cloud_recaptchaenterprise_v1_firewall_policy_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy
Creates a new FirewallPolicy, specifying conditions at which reCAPTCHA Enterprise actions can be executed. A project may have a maximum of 1000 policies.
148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 148 def create_project_firewallpolicy(parent, google_cloud_recaptchaenterprise_v1_firewall_policy_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/firewallpolicies', ) command.request_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy::Representation command.request_object = google_cloud_recaptchaenterprise_v1_firewall_policy_object command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_key(parent, google_cloud_recaptchaenterprise_v1_key_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key
Creates a new reCAPTCHA Enterprise key.
391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 391 def create_project_key(parent, google_cloud_recaptchaenterprise_v1_key_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/keys', ) command.request_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key::Representation command.request_object = google_cloud_recaptchaenterprise_v1_key_object command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_firewallpolicy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleProtobufEmpty
Deletes the specified firewall policy.
181 182 183 184 185 186 187 188 189 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 181 def delete_project_firewallpolicy(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_key(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleProtobufEmpty
Deletes the specified key.
424 425 426 427 428 429 430 431 432 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 424 def delete_project_key(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_firewallpolicy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy
Returns the specified firewall policy.
212 213 214 215 216 217 218 219 220 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 212 def get_project_firewallpolicy(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_key(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key
Returns the specified key.
455 456 457 458 459 460 461 462 463 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 455 def get_project_key(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_key_metrics(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Metrics
Get some aggregated metrics for a Key. This data can be used to build dashboards.
487 488 489 490 491 492 493 494 495 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 487 def get_project_key_metrics(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Metrics::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Metrics command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_key_policy(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Policy
Get the policy for a key.
518 519 520 521 522 523 524 525 526 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 518 def get_project_key_policy(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Policy::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Policy command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_firewallpolicies(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListFirewallPoliciesResponse
Returns the list of all firewall policies that belong to a project.
249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 249 def list_project_firewallpolicies(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/firewallpolicies', ) command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListFirewallPoliciesResponse::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListFirewallPoliciesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_key_ip_overrides(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListIpOverridesResponse
Lists all IP overrides for a key.
595 596 597 598 599 600 601 602 603 604 605 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 595 def list_project_key_ip_overrides(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}:listIpOverrides', ) command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListIpOverridesResponse::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListIpOverridesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_keys(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListKeysResponse
Returns the list of all keys that belong to a project.
555 556 557 558 559 560 561 562 563 564 565 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 555 def list_project_keys(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/keys', ) command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListKeysResponse::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListKeysResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_relatedaccountgroup_memberships(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupMembershipsResponse
Get memberships in a group of related accounts.
896 897 898 899 900 901 902 903 904 905 906 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 896 def (parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/memberships', ) command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupMembershipsResponse::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupMembershipsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_relatedaccountgroups(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupsResponse
List groups of related accounts.
854 855 856 857 858 859 860 861 862 863 864 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 854 def (parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/relatedaccountgroups', ) command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupsResponse::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ListRelatedAccountGroupsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#migrate_project_key(name, google_cloud_recaptchaenterprise_v1_migrate_key_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key
Migrates an existing key from reCAPTCHA to reCAPTCHA Enterprise. Once a key is migrated, it can be used from either product. SiteVerify requests are billed as CreateAssessment calls. You must be authenticated as one of the current owners of the reCAPTCHA Key, and your user must have the reCAPTCHA Enterprise Admin IAM role in the destination project.
633 634 635 636 637 638 639 640 641 642 643 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 633 def migrate_project_key(name, google_cloud_recaptchaenterprise_v1_migrate_key_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:migrate', ) command.request_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1MigrateKeyRequest::Representation command.request_object = google_cloud_recaptchaenterprise_v1_migrate_key_request_object command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_firewallpolicy(name, google_cloud_recaptchaenterprise_v1_firewall_policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy
Updates the specified firewall policy.
286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 286 def patch_project_firewallpolicy(name, google_cloud_recaptchaenterprise_v1_firewall_policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy::Representation command.request_object = google_cloud_recaptchaenterprise_v1_firewall_policy_object command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_key(name, google_cloud_recaptchaenterprise_v1_key_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key
Updates the specified key.
670 671 672 673 674 675 676 677 678 679 680 681 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 670 def patch_project_key(name, google_cloud_recaptchaenterprise_v1_key_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key::Representation command.request_object = google_cloud_recaptchaenterprise_v1_key_object command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#remove_project_key_ip_override(name, google_cloud_recaptchaenterprise_v1_remove_ip_override_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1RemoveIpOverrideResponse
Removes an IP override from a key. The following restrictions hold: * If the
IP isn't found in an existing IP override, a NOT_FOUND error is returned. *
If the IP is found in an existing IP override, but the override type does not
match, a NOT_FOUND error is returned.
708 709 710 711 712 713 714 715 716 717 718 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 708 def remove_project_key_ip_override(name, google_cloud_recaptchaenterprise_v1_remove_ip_override_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:removeIpOverride', ) command.request_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1RemoveIpOverrideRequest::Representation command.request_object = google_cloud_recaptchaenterprise_v1_remove_ip_override_request_object command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1RemoveIpOverrideResponse::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1RemoveIpOverrideResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#reorder_project_firewallpolicy(parent, google_cloud_recaptchaenterprise_v1_reorder_firewall_policies_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ReorderFirewallPoliciesResponse
Reorders all firewall policies.
321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 321 def reorder_project_firewallpolicy(parent, google_cloud_recaptchaenterprise_v1_reorder_firewall_policies_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/firewallpolicies:reorder', ) command.request_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ReorderFirewallPoliciesRequest::Representation command.request_object = google_cloud_recaptchaenterprise_v1_reorder_firewall_policies_request_object command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ReorderFirewallPoliciesResponse::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ReorderFirewallPoliciesResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#retrieve_project_key_legacy_secret_key(key, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponse
Returns the secret key related to the specified public key. You must use the legacy secret key only in a 3rd party integration with legacy reCAPTCHA.
742 743 744 745 746 747 748 749 750 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 742 def retrieve_project_key_legacy_secret_key(key, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+key}:retrieveLegacySecretKey', ) command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponse::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponse command.params['key'] = key unless key.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_project_relatedaccountgroupmemberships(project, google_cloud_recaptchaenterprise_v1_search_related_account_group_memberships_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsResponse
Search group memberships related to a given account.
812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 812 def (project, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+project}/relatedaccountgroupmemberships:search', ) command.request_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsRequest::Representation command.request_object = command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsResponse::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsResponse command.params['project'] = project unless project.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_key_policy(name, google_cloud_recaptchaenterprise_v1_policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Policy
Updates the policy for a key.
777 778 779 780 781 782 783 784 785 786 787 788 |
# File 'lib/google/apis/recaptchaenterprise_v1/service.rb', line 777 def update_project_key_policy(name, google_cloud_recaptchaenterprise_v1_policy_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Policy::Representation command.request_object = google_cloud_recaptchaenterprise_v1_policy_object command.response_representation = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Policy::Representation command.response_class = Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Policy command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |