Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentRequest
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
The request message to annotate an Assessment.
Instance Attribute Summary collapse
-
#account_id ⇒ String
Optional.
-
#annotation ⇒ String
Optional.
-
#hashed_account_id ⇒ String
Optional.
-
#phone_authentication_event ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1PhoneAuthenticationEvent
Details on a phone authentication event Corresponds to the JSON property
phoneAuthenticationEvent. -
#reasons ⇒ Array<String>
Optional.
-
#transaction_event ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionEvent
Describes an event in the lifecycle of a payment transaction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentRequest
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentRequest
Returns a new instance of GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentRequest.
276 277 278 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 276 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
Optional. A stable account identifier to apply to the assessment. This is an
alternative to setting account_id in CreateAssessment, for example when a
stable account identifier is not yet known in the initial request.
Corresponds to the JSON property accountId
243 244 245 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 243 def account_id @account_id end |
#annotation ⇒ String
Optional. The annotation that is assigned to the Event. This field can be left
empty to provide reasons that apply to an event without concluding whether the
event is legitimate or fraudulent.
Corresponds to the JSON property annotation
250 251 252 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 250 def annotation @annotation end |
#hashed_account_id ⇒ String
Optional. A stable hashed account identifier to apply to the assessment. This
is an alternative to setting hashed_account_id in CreateAssessment, for
example when a stable account identifier is not yet known in the initial
request.
Corresponds to the JSON property hashedAccountId
NOTE: Values are automatically base64 encoded/decoded in the client library.
259 260 261 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 259 def hashed_account_id @hashed_account_id end |
#phone_authentication_event ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1PhoneAuthenticationEvent
Details on a phone authentication event
Corresponds to the JSON property phoneAuthenticationEvent
264 265 266 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 264 def phone_authentication_event @phone_authentication_event end |
#reasons ⇒ Array<String>
Optional. Reasons for the annotation that are assigned to the event.
Corresponds to the JSON property reasons
269 270 271 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 269 def reasons @reasons end |
#transaction_event ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionEvent
Describes an event in the lifecycle of a payment transaction.
Corresponds to the JSON property transactionEvent
274 275 276 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 274 def transaction_event @transaction_event end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
281 282 283 284 285 286 287 288 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 281 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @annotation = args[:annotation] if args.key?(:annotation) @hashed_account_id = args[:hashed_account_id] if args.key?(:hashed_account_id) @phone_authentication_event = args[:phone_authentication_event] if args.key?(:phone_authentication_event) @reasons = args[:reasons] if args.key?(:reasons) @transaction_event = args[:transaction_event] if args.key?(:transaction_event) end |