Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

The request message to annotate an Assessment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentRequest

Returns a new instance of GoogleCloudRecaptchaenterpriseV1AnnotateAssessmentRequest.



196
197
198
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 196

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

Optional. A stable account identifier to apply to the assessment. This is an alternative to setting account_id in CreateAssessment, for example when a stable account identifier is not yet known in the initial request. Corresponds to the JSON property accountId

Returns:

  • (String)


163
164
165
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 163

def 
  @account_id
end

#annotationString

Optional. The annotation that is assigned to the Event. This field can be left empty to provide reasons that apply to an event without concluding whether the event is legitimate or fraudulent. Corresponds to the JSON property annotation

Returns:

  • (String)


170
171
172
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 170

def annotation
  @annotation
end

#hashed_account_idString

Optional. A stable hashed account identifier to apply to the assessment. This is an alternative to setting hashed_account_id in CreateAssessment, for example when a stable account identifier is not yet known in the initial request. Corresponds to the JSON property hashedAccountId NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


179
180
181
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 179

def 
  @hashed_account_id
end

#phone_authentication_eventGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1PhoneAuthenticationEvent

Details on a phone authentication event Corresponds to the JSON property phoneAuthenticationEvent



184
185
186
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 184

def phone_authentication_event
  @phone_authentication_event
end

#reasonsArray<String>

Optional. Reasons for the annotation that are assigned to the event. Corresponds to the JSON property reasons

Returns:

  • (Array<String>)


189
190
191
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 189

def reasons
  @reasons
end

#transaction_eventGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionEvent

Describes an event in the lifecycle of a payment transaction. Corresponds to the JSON property transactionEvent



194
195
196
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 194

def transaction_event
  @transaction_event
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



201
202
203
204
205
206
207
208
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 201

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @annotation = args[:annotation] if args.key?(:annotation)
  @hashed_account_id = args[:hashed_account_id] if args.key?(:hashed_account_id)
  @phone_authentication_event = args[:phone_authentication_event] if args.key?(:phone_authentication_event)
  @reasons = args[:reasons] if args.key?(:reasons)
  @transaction_event = args[:transaction_event] if args.key?(:transaction_event)
end