Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Bot
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Bot
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Bot information and metadata.
Instance Attribute Summary collapse
-
#bot_type ⇒ String
Optional.
-
#name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1Bot
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1Bot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1Bot
Returns a new instance of GoogleCloudRecaptchaenterpriseV1Bot.
484 485 486 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 484 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bot_type ⇒ String
Optional. Enumerated field representing the type of bot.
Corresponds to the JSON property botType
467 468 469 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 467 def bot_type @bot_type end |
#name ⇒ String
Optional. Enumerated string value that indicates the identity of the bot,
formatted in kebab-case. Current example values include the following: *
google-agent - AI_AGENT * browser-base - AI_AGENT * chat-gpt - AI_AGENT * aws-
bedrock - AI_AGENT * cybaa-bot - AI_AGENT * cloudflare - AI_AGENT * payhawk -
AI_AGENT * duck-duck-go - SEARCH_INDEXER * mediaboard - CONTENT_SCRAPER *
marker-io - AI_AGENT * broadcom - AI_AGENT * anchor-browser - AI_AGENT *
shopify - AI_AGENT * stackscope - CONTENT_SCRAPER * manus - AI_AGENT * kernel-
sh - AI_AGENT * zvelo - SEARCH_INDEXER Ensure that your applications can
handle identifier values not explicitly listed here. Deprecated values might
take some time to stop showing up in responses. New values can be pushed so
this list should be taken as non exhaustive.
Corresponds to the JSON property name
482 483 484 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 482 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
489 490 491 492 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 489 def update!(**args) @bot_type = args[:bot_type] if args.key?(:bot_type) @name = args[:name] if args.key?(:name) end |