Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Bot

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Bot information and metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1Bot

Returns a new instance of GoogleCloudRecaptchaenterpriseV1Bot.



480
481
482
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 480

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bot_typeString

Optional. Enumerated field representing the type of bot. Corresponds to the JSON property botType

Returns:

  • (String)


467
468
469
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 467

def bot_type
  @bot_type
end

#nameString

Optional. Enumerated string value that indicates the identity of the bot, formatted in kebab-case. Current example values include the following: * google-agent * browser-base * chat-gpt * aws-bedrock * cybaa-bot * cloudflare * payhawk Ensure that your applications can handle identifier values not explicitly listed here. Deprecated values might take some time to stop showing up in responses. New values can be pushed so this list should be taken as non exhaustive. Corresponds to the JSON property name

Returns:

  • (String)


478
479
480
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 478

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



485
486
487
488
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 485

def update!(**args)
  @bot_type = args[:bot_type] if args.key?(:bot_type)
  @name = args[:name] if args.key?(:name)
end