Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Bot
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Bot
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Bot information and metadata.
Instance Attribute Summary collapse
-
#bot_type ⇒ String
Optional.
-
#name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1Bot
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1Bot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1Bot
Returns a new instance of GoogleCloudRecaptchaenterpriseV1Bot.
474 475 476 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 474 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bot_type ⇒ String
Optional. Enumerated field representing the type of bot.
Corresponds to the JSON property botType
461 462 463 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 461 def bot_type @bot_type end |
#name ⇒ String
Optional. Enumerated string value that indicates the identity of the bot,
formatted in kebab-case. Current example values include the following: *
google-agent * browser-base * chat-gpt * aws-bedrock * cybaa-bot * cloudflare *
payhawk Ensure that your applications can handle identifier values not
explicitly listed here. Deprecated values might take some time to stop showing
up in responses. New values can be pushed so this list should be taken as non
exhaustive.
Corresponds to the JSON property name
472 473 474 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 472 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
479 480 481 482 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 479 def update!(**args) @bot_type = args[:bot_type] if args.key?(:bot_type) @name = args[:name] if args.key?(:name) end |