Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ChallengeRuleChallengeOutcome
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ChallengeRuleChallengeOutcome
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
An outcome that indicates that a challenge of a specified difficulty should be presented to the user.
Instance Attribute Summary collapse
-
#difficulty ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1ChallengeRuleChallengeOutcome
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1ChallengeRuleChallengeOutcome.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1ChallengeRuleChallengeOutcome
Returns a new instance of GoogleCloudRecaptchaenterpriseV1ChallengeRuleChallengeOutcome.
580 581 582 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 580 def initialize(**args) update!(**args) end |
Instance Attribute Details
#difficulty ⇒ String
Optional. The difficulty of the challenge to present to the user. If
unspecified, BALANCE is used.
Corresponds to the JSON property difficulty
578 579 580 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 578 def difficulty @difficulty end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
585 586 587 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 585 def update!(**args) @difficulty = args[:difficulty] if args.key?(:difficulty) end |