Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Event
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Event
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
The event being assessed.
Instance Attribute Summary collapse
-
#expected_action ⇒ String
Optional.
-
#express ⇒ Boolean
(also: #express?)
Optional.
-
#firewall_policy_evaluation ⇒ Boolean
(also: #firewall_policy_evaluation?)
Optional.
-
#fraud_prevention ⇒ String
Optional.
-
#hashed_account_id ⇒ String
Optional.
-
#headers ⇒ Array<String>
Optional.
-
#ja3 ⇒ String
Optional.
-
#ja4 ⇒ String
Optional.
-
#requested_uri ⇒ String
Optional.
-
#site_key ⇒ String
Optional.
-
#token ⇒ String
Optional.
-
#transaction_data ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionData
Transaction data associated with a payment protected by reCAPTCHA Enterprise.
-
#user_agent ⇒ String
Optional.
-
#user_info ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1UserInfo
User information associated with a request protected by reCAPTCHA Enterprise.
-
#user_ip_address ⇒ String
Optional.
-
#waf_token_assessment ⇒ Boolean
(also: #waf_token_assessment?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1Event
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1Event.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1Event
Returns a new instance of GoogleCloudRecaptchaenterpriseV1Event.
583 584 585 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 583 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expected_action ⇒ String
Optional. The expected action for this type of event. This should be the same
action provided at token generation time on client-side platforms already
integrated with recaptcha enterprise.
Corresponds to the JSON property expectedAction
489 490 491 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 489 def expected_action @expected_action end |
#express ⇒ Boolean Also known as: express?
Optional. Flag for a reCAPTCHA express request for an assessment without a
token. If enabled, site_key must reference an Express site key.
Corresponds to the JSON property express
495 496 497 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 495 def express @express end |
#firewall_policy_evaluation ⇒ Boolean Also known as: firewall_policy_evaluation?
Optional. Flag for enabling firewall policy config assessment. If this flag is
enabled, the firewall policy is evaluated and a suggested firewall action is
returned in the response.
Corresponds to the JSON property firewallPolicyEvaluation
503 504 505 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 503 def firewall_policy_evaluation @firewall_policy_evaluation end |
#fraud_prevention ⇒ String
Optional. The Fraud Prevention setting for this assessment.
Corresponds to the JSON property fraudPrevention
509 510 511 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 509 def fraud_prevention @fraud_prevention end |
#hashed_account_id ⇒ String
Optional. Deprecated: use user_info.account_id instead. Unique stable hashed
user identifier for the request. The identifier must be hashed using hmac-
sha256 with stable secret.
Corresponds to the JSON property hashedAccountId
NOTE: Values are automatically base64 encoded/decoded in the client library.
517 518 519 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 517 def hashed_account_id @hashed_account_id end |
#headers ⇒ Array<String>
Optional. HTTP header information about the request.
Corresponds to the JSON property headers
522 523 524 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 522 def headers @headers end |
#ja3 ⇒ String
Optional. JA3 fingerprint for SSL clients. To learn how to compute this
fingerprint, please refer to https://github.com/salesforce/ja3.
Corresponds to the JSON property ja3
528 529 530 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 528 def ja3 @ja3 end |
#ja4 ⇒ String
Optional. JA4 fingerprint for SSL clients. To learn how to compute this
fingerprint, please refer to https://github.com/FoxIO-LLC/ja4.
Corresponds to the JSON property ja4
534 535 536 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 534 def ja4 @ja4 end |
#requested_uri ⇒ String
Optional. The URI resource the user requested that triggered an assessment.
Corresponds to the JSON property requestedUri
539 540 541 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 539 def requested_uri @requested_uri end |
#site_key ⇒ String
Optional. The site key that was used to invoke reCAPTCHA Enterprise on your
site and generate the token.
Corresponds to the JSON property siteKey
545 546 547 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 545 def site_key @site_key end |
#token ⇒ String
Optional. The user response token provided by the reCAPTCHA Enterprise client-
side integration on your site.
Corresponds to the JSON property token
551 552 553 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 551 def token @token end |
#transaction_data ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionData
Transaction data associated with a payment protected by reCAPTCHA Enterprise.
Corresponds to the JSON property transactionData
556 557 558 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 556 def transaction_data @transaction_data end |
#user_agent ⇒ String
Optional. The user agent present in the request from the user's device related
to this event.
Corresponds to the JSON property userAgent
562 563 564 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 562 def user_agent @user_agent end |
#user_info ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1UserInfo
User information associated with a request protected by reCAPTCHA Enterprise.
Corresponds to the JSON property userInfo
567 568 569 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 567 def user_info @user_info end |
#user_ip_address ⇒ String
Optional. The IP address in the request from the user's device related to this
event.
Corresponds to the JSON property userIpAddress
573 574 575 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 573 def user_ip_address @user_ip_address end |
#waf_token_assessment ⇒ Boolean Also known as: waf_token_assessment?
Optional. Flag for running Web Application Firewall (WAF) token assessment. If
enabled, the token must be specified, and have been created by a WAF-enabled
key.
Corresponds to the JSON property wafTokenAssessment
580 581 582 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 580 def waf_token_assessment @waf_token_assessment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 588 def update!(**args) @expected_action = args[:expected_action] if args.key?(:expected_action) @express = args[:express] if args.key?(:express) @firewall_policy_evaluation = args[:firewall_policy_evaluation] if args.key?(:firewall_policy_evaluation) @fraud_prevention = args[:fraud_prevention] if args.key?(:fraud_prevention) @hashed_account_id = args[:hashed_account_id] if args.key?(:hashed_account_id) @headers = args[:headers] if args.key?(:headers) @ja3 = args[:ja3] if args.key?(:ja3) @ja4 = args[:ja4] if args.key?(:ja4) @requested_uri = args[:requested_uri] if args.key?(:requested_uri) @site_key = args[:site_key] if args.key?(:site_key) @token = args[:token] if args.key?(:token) @transaction_data = args[:transaction_data] if args.key?(:transaction_data) @user_agent = args[:user_agent] if args.key?(:user_agent) @user_info = args[:user_info] if args.key?(:user_info) @user_ip_address = args[:user_ip_address] if args.key?(:user_ip_address) @waf_token_assessment = args[:waf_token_assessment] if args.key?(:waf_token_assessment) end |