Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
A FirewallPolicy represents a single matching pattern and resulting actions to take.
Instance Attribute Summary collapse
-
#actions ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallAction>
Optional.
-
#condition ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#path ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FirewallPolicy
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1FirewallPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FirewallPolicy
Returns a new instance of GoogleCloudRecaptchaenterpriseV1FirewallPolicy.
828 829 830 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 828 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallAction>
Optional. The actions that the caller should take regarding user access. There
should be at most one terminal action. A terminal action is any action that
forces a response, such as AllowAction, BlockAction or SubstituteAction.
Zero or more non-terminal actions such as SetHeader might be specified. A
single policy can contain up to 16 actions.
Corresponds to the JSON property actions
795 796 797 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 795 def actions @actions end |
#condition ⇒ String
Optional. A CEL (Common Expression Language) conditional expression that
specifies if this policy applies to an incoming user request. If this
condition evaluates to true and the requested path matched the path pattern,
the associated actions should be executed by the caller. The condition string
is checked for CEL syntax correctness on creation. For more information, see
the CEL spec and its language
definition. A
condition has a max length of 500 characters.
Corresponds to the JSON property condition
807 808 809 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 807 def condition @condition end |
#description ⇒ String
Optional. A description of what this policy aims to achieve, for convenience
purposes. The description can at most include 256 UTF-8 characters.
Corresponds to the JSON property description
813 814 815 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 813 def description @description end |
#name ⇒ String
Identifier. The resource name for the FirewallPolicy in the format projects/
project/firewallpolicies/firewallpolicy`.
Corresponds to the JSON propertyname`
819 820 821 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 819 def name @name end |
#path ⇒ String
Optional. The path for which this policy applies, specified as a glob pattern.
For more information on glob, see the manual page. A path has a max length of 200 characters.
Corresponds to the JSON property path
826 827 828 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 826 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
833 834 835 836 837 838 839 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 833 def update!(**args) @actions = args[:actions] if args.key?(:actions) @condition = args[:condition] if args.key?(:condition) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) end |