Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Policy config assessment.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#firewall_policy ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy
A FirewallPolicy represents a single matching pattern and resulting actions to take.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment
Returns a new instance of GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment.
1108 1109 1110 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1100 1101 1102 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1100 def error @error end |
#firewall_policy ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy
A FirewallPolicy represents a single matching pattern and resulting actions to
take.
Corresponds to the JSON property firewallPolicy
1106 1107 1108 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1106 def firewall_policy @firewall_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1113 1114 1115 1116 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1113 def update!(**args) @error = args[:error] if args.key?(:error) @firewall_policy = args[:firewall_policy] if args.key?(:firewall_policy) end |