Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Policy config assessment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment

Returns a new instance of GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment.



942
943
944
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::RecaptchaenterpriseV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



934
935
936
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 934

def error
  @error
end

#firewall_policyGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy

A FirewallPolicy represents a single matching pattern and resulting actions to take. Corresponds to the JSON property firewallPolicy



940
941
942
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 940

def firewall_policy
  @firewall_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



947
948
949
950
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 947

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @firewall_policy = args[:firewall_policy] if args.key?(:firewall_policy)
end