Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Policy config assessment.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#firewall_policy ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy
A FirewallPolicy represents a single matching pattern and resulting actions to take.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment
Returns a new instance of GoogleCloudRecaptchaenterpriseV1FirewallPolicyAssessment.
942 943 944 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 942 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
934 935 936 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 934 def error @error end |
#firewall_policy ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FirewallPolicy
A FirewallPolicy represents a single matching pattern and resulting actions to
take.
Corresponds to the JSON property firewallPolicy
940 941 942 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 940 def firewall_policy @firewall_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
947 948 949 950 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 947 def update!(**args) @error = args[:error] if args.key?(:error) @firewall_policy = args[:firewall_policy] if args.key?(:firewall_policy) end |