Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessment
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Assessment for Fraud Prevention.
Instance Attribute Summary collapse
-
#behavioral_trust_verdict ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentBehavioralTrustVerdict
Information about behavioral trust of the transaction.
-
#card_testing_verdict ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentCardTestingVerdict
Information about card testing fraud, where an adversary is testing fraudulently obtained cards or brute forcing their details.
-
#risk_reasons ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentRiskReason>
Output only.
-
#stolen_instrument_verdict ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentStolenInstrumentVerdict
Information about stolen instrument fraud, where the user is not the legitimate owner of the instrument being used for the purchase.
-
#transaction_risk ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessment
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessment
Returns a new instance of GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessment.
1153 1154 1155 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1153 def initialize(**args) update!(**args) end |
Instance Attribute Details
#behavioral_trust_verdict ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentBehavioralTrustVerdict
Information about behavioral trust of the transaction.
Corresponds to the JSON property behavioralTrustVerdict
1126 1127 1128 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1126 def behavioral_trust_verdict @behavioral_trust_verdict end |
#card_testing_verdict ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentCardTestingVerdict
Information about card testing fraud, where an adversary is testing
fraudulently obtained cards or brute forcing their details.
Corresponds to the JSON property cardTestingVerdict
1132 1133 1134 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1132 def card_testing_verdict @card_testing_verdict end |
#risk_reasons ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentRiskReason>
Output only. Reasons why the transaction is probably fraudulent and received a
high transaction risk score.
Corresponds to the JSON property riskReasons
1138 1139 1140 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1138 def risk_reasons @risk_reasons end |
#stolen_instrument_verdict ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentStolenInstrumentVerdict
Information about stolen instrument fraud, where the user is not the
legitimate owner of the instrument being used for the purchase.
Corresponds to the JSON property stolenInstrumentVerdict
1144 1145 1146 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1144 def stolen_instrument_verdict @stolen_instrument_verdict end |
#transaction_risk ⇒ Float
Output only. Probability of this transaction being fraudulent. Summarizes the
combined risk of attack vectors below. Values are from 0.0 (lowest) to 1.0 (
highest).
Corresponds to the JSON property transactionRisk
1151 1152 1153 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1151 def transaction_risk @transaction_risk end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1158 1159 1160 1161 1162 1163 1164 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1158 def update!(**args) @behavioral_trust_verdict = args[:behavioral_trust_verdict] if args.key?(:behavioral_trust_verdict) @card_testing_verdict = args[:card_testing_verdict] if args.key?(:card_testing_verdict) @risk_reasons = args[:risk_reasons] if args.key?(:risk_reasons) @stolen_instrument_verdict = args[:stolen_instrument_verdict] if args.key?(:stolen_instrument_verdict) @transaction_risk = args[:transaction_risk] if args.key?(:transaction_risk) end |