Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Assessment for Fraud Prevention.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessment

Returns a new instance of GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessment.



907
908
909
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behavioral_trust_verdictGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentBehavioralTrustVerdict

Information about behavioral trust of the transaction. Corresponds to the JSON property behavioralTrustVerdict



880
881
882
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 880

def behavioral_trust_verdict
  @behavioral_trust_verdict
end

#card_testing_verdictGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentCardTestingVerdict

Information about card testing fraud, where an adversary is testing fraudulently obtained cards or brute forcing their details. Corresponds to the JSON property cardTestingVerdict



886
887
888
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 886

def card_testing_verdict
  @card_testing_verdict
end

#risk_reasonsArray<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentRiskReason>

Output only. Reasons why the transaction is probably fraudulent and received a high transaction risk score. Corresponds to the JSON property riskReasons



892
893
894
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 892

def risk_reasons
  @risk_reasons
end

#stolen_instrument_verdictGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudPreventionAssessmentStolenInstrumentVerdict

Information about stolen instrument fraud, where the user is not the legitimate owner of the instrument being used for the purchase. Corresponds to the JSON property stolenInstrumentVerdict



898
899
900
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 898

def stolen_instrument_verdict
  @stolen_instrument_verdict
end

#transaction_riskFloat

Output only. Probability of this transaction being fraudulent. Summarizes the combined risk of attack vectors below. Values are from 0.0 (lowest) to 1.0 ( highest). Corresponds to the JSON property transactionRisk

Returns:

  • (Float)


905
906
907
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 905

def transaction_risk
  @transaction_risk
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



912
913
914
915
916
917
918
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 912

def update!(**args)
  @behavioral_trust_verdict = args[:behavioral_trust_verdict] if args.key?(:behavioral_trust_verdict)
  @card_testing_verdict = args[:card_testing_verdict] if args.key?(:card_testing_verdict)
  @risk_reasons = args[:risk_reasons] if args.key?(:risk_reasons)
  @stolen_instrument_verdict = args[:stolen_instrument_verdict] if args.key?(:stolen_instrument_verdict)
  @transaction_risk = args[:transaction_risk] if args.key?(:transaction_risk)
end