Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Signals describing the user involved in this transaction.
Instance Attribute Summary collapse
-
#active_days_lower_bound ⇒ Fixnum
Output only.
-
#synthetic_risk ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals
Returns a new instance of GoogleCloudRecaptchaenterpriseV1FraudSignalsUserSignals.
1063 1064 1065 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1063 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_days_lower_bound ⇒ Fixnum
Output only. This user (based on email, phone, and other identifiers) has been
seen on the internet for at least this number of days.
Corresponds to the JSON property activeDaysLowerBound
1054 1055 1056 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1054 def active_days_lower_bound @active_days_lower_bound end |
#synthetic_risk ⇒ Float
Output only. Likelihood (from 0.0 to 1.0) this user includes synthetic
components in their identity, such as a randomly generated email address,
temporary phone number, or fake shipping address.
Corresponds to the JSON property syntheticRisk
1061 1062 1063 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1061 def synthetic_risk @synthetic_risk end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1068 1069 1070 1071 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1068 def update!(**args) @active_days_lower_bound = args[:active_days_lower_bound] if args.key?(:active_days_lower_bound) @synthetic_risk = args[:synthetic_risk] if args.key?(:synthetic_risk) end |