Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1IosKeySettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Settings specific to keys that can be used by iOS apps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1IosKeySettings

Returns a new instance of GoogleCloudRecaptchaenterpriseV1IosKeySettings.



1099
1100
1101
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_all_bundle_idsBoolean Also known as: allow_all_bundle_ids?

Optional. If set to true, allowed_bundle_ids are not enforced. Corresponds to the JSON property allowAllBundleIds

Returns:

  • (Boolean)


1081
1082
1083
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1081

def allow_all_bundle_ids
  @allow_all_bundle_ids
end

#allowed_bundle_idsArray<String>

Optional. iOS bundle IDs of apps allowed to use the key. Example: 'com. companyname.productname.appname' Each key supports a maximum of 250 bundle IDs. To use a key on more apps, set allow_all_bundle_ids to true. When this is set, you are responsible for validating the bundle id by checking the token_properties.ios_bundle_id field in each assessment response against your list of allowed bundle IDs. Corresponds to the JSON property allowedBundleIds

Returns:

  • (Array<String>)


1092
1093
1094
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1092

def allowed_bundle_ids
  @allowed_bundle_ids
end

#apple_developer_idGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AppleDeveloperId

Contains fields that are required to perform Apple-specific integrity checks. Corresponds to the JSON property appleDeveloperId



1097
1098
1099
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1097

def apple_developer_id
  @apple_developer_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1104
1105
1106
1107
1108
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1104

def update!(**args)
  @allow_all_bundle_ids = args[:allow_all_bundle_ids] if args.key?(:allow_all_bundle_ids)
  @allowed_bundle_ids = args[:allowed_bundle_ids] if args.key?(:allowed_bundle_ids)
  @apple_developer_id = args[:apple_developer_id] if args.key?(:apple_developer_id)
end