Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

A key used to identify and configure applications (web and/or mobile) that use reCAPTCHA Enterprise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1Key

Returns a new instance of GoogleCloudRecaptchaenterpriseV1Key.



1448
1449
1450
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1448

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#android_settingsGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AndroidKeySettings

Settings specific to keys that can be used by Android apps. Corresponds to the JSON property androidSettings



1394
1395
1396
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1394

def android_settings
  @android_settings
end

#create_timeString

Output only. The timestamp corresponding to the creation of this key. Corresponds to the JSON property createTime

Returns:

  • (String)


1399
1400
1401
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1399

def create_time
  @create_time
end

#display_nameString

Required. Human-readable display name of this key. Modifiable by user. Corresponds to the JSON property displayName

Returns:

  • (String)


1404
1405
1406
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1404

def display_name
  @display_name
end

#express_settingsGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ExpressKeySettings

Settings specific to keys that can be used for reCAPTCHA Express. Corresponds to the JSON property expressSettings



1409
1410
1411
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1409

def express_settings
  @express_settings
end

#ios_settingsGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1IosKeySettings

Settings specific to keys that can be used by iOS apps. Corresponds to the JSON property iosSettings



1414
1415
1416
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1414

def ios_settings
  @ios_settings
end

#labelsHash<String,String>

Optional. See Creating and managing labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1420
1421
1422
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1420

def labels
  @labels
end

#nameString

Identifier. The resource name for the Key in the format projects/project/ keys/key`. Corresponds to the JSON propertyname`

Returns:

  • (String)


1426
1427
1428
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1426

def name
  @name
end

#testing_optionsGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TestingOptions

Options for user acceptance testing. Corresponds to the JSON property testingOptions



1431
1432
1433
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1431

def testing_options
  @testing_options
end

#universal_settingsGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1UniversalKeySettings

Settings for keys that are configured through their Policy. Corresponds to the JSON property universalSettings



1436
1437
1438
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1436

def universal_settings
  @universal_settings
end

#waf_settingsGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WafSettings

Settings specific to keys that can be used for WAF (Web Application Firewall). Corresponds to the JSON property wafSettings



1441
1442
1443
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1441

def waf_settings
  @waf_settings
end

#web_settingsGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettings

Settings specific to keys that can be used by websites. Corresponds to the JSON property webSettings



1446
1447
1448
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1446

def web_settings
  @web_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1453

def update!(**args)
  @android_settings = args[:android_settings] if args.key?(:android_settings)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @express_settings = args[:express_settings] if args.key?(:express_settings)
  @ios_settings = args[:ios_settings] if args.key?(:ios_settings)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @testing_options = args[:testing_options] if args.key?(:testing_options)
  @universal_settings = args[:universal_settings] if args.key?(:universal_settings)
  @waf_settings = args[:waf_settings] if args.key?(:waf_settings)
  @web_settings = args[:web_settings] if args.key?(:web_settings)
end