Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Key
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
A key used to identify and configure applications (web and/or mobile) that use reCAPTCHA Enterprise.
Instance Attribute Summary collapse
-
#android_settings ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AndroidKeySettings
Settings specific to keys that can be used by Android apps.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#express_settings ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ExpressKeySettings
Settings specific to keys that can be used for reCAPTCHA Express.
-
#ios_settings ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1IosKeySettings
Settings specific to keys that can be used by iOS apps.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#testing_options ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TestingOptions
Options for user acceptance testing.
-
#waf_settings ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WafSettings
Settings specific to keys that can be used for WAF (Web Application Firewall).
-
#web_settings ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettings
Settings specific to keys that can be used by websites.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1Key
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1Key.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1Key
Returns a new instance of GoogleCloudRecaptchaenterpriseV1Key.
1197 1198 1199 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1197 def initialize(**args) update!(**args) end |
Instance Attribute Details
#android_settings ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1AndroidKeySettings
Settings specific to keys that can be used by Android apps.
Corresponds to the JSON property androidSettings
1148 1149 1150 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1148 def android_settings @android_settings end |
#create_time ⇒ String
Output only. The timestamp corresponding to the creation of this key.
Corresponds to the JSON property createTime
1153 1154 1155 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1153 def create_time @create_time end |
#display_name ⇒ String
Required. Human-readable display name of this key. Modifiable by user.
Corresponds to the JSON property displayName
1158 1159 1160 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1158 def display_name @display_name end |
#express_settings ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ExpressKeySettings
Settings specific to keys that can be used for reCAPTCHA Express.
Corresponds to the JSON property expressSettings
1163 1164 1165 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1163 def express_settings @express_settings end |
#ios_settings ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1IosKeySettings
Settings specific to keys that can be used by iOS apps.
Corresponds to the JSON property iosSettings
1168 1169 1170 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1168 def ios_settings @ios_settings end |
#labels ⇒ Hash<String,String>
Optional. See Creating and managing labels.
Corresponds to the JSON property labels
1174 1175 1176 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1174 def labels @labels end |
#name ⇒ String
Identifier. The resource name for the Key in the format projects/project/
keys/key`.
Corresponds to the JSON propertyname`
1180 1181 1182 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1180 def name @name end |
#testing_options ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TestingOptions
Options for user acceptance testing.
Corresponds to the JSON property testingOptions
1185 1186 1187 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1185 def @testing_options end |
#waf_settings ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WafSettings
Settings specific to keys that can be used for WAF (Web Application Firewall).
Corresponds to the JSON property wafSettings
1190 1191 1192 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1190 def waf_settings @waf_settings end |
#web_settings ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettings
Settings specific to keys that can be used by websites.
Corresponds to the JSON property webSettings
1195 1196 1197 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1195 def web_settings @web_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1202 def update!(**args) @android_settings = args[:android_settings] if args.key?(:android_settings) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @express_settings = args[:express_settings] if args.key?(:express_settings) @ios_settings = args[:ios_settings] if args.key?(:ios_settings) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @testing_options = args[:testing_options] if args.key?(:testing_options) @waf_settings = args[:waf_settings] if args.key?(:waf_settings) @web_settings = args[:web_settings] if args.key?(:web_settings) end |