Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ProtectedEndpointGroup
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ProtectedEndpointGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Configuration for API endpoints to protect with reCAPTCHA.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1ProtectedEndpointGroup
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1ProtectedEndpointGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1ProtectedEndpointGroup
Returns a new instance of GoogleCloudRecaptchaenterpriseV1ProtectedEndpointGroup.
1861 1862 1863 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1861 def initialize(**args) update!(**args) end |
Instance Attribute Details
#protected_endpoints ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1ProtectedEndpoint>
Optional. List of API endpoints to automatically protect with reCAPTCHA. If
any of these endpoints is invoked from a page where a key bound to this policy
is installed, a reCAPTCHA token is automatically generated and attached to the
request. If multiple protected endpoints match a given API endpoint, the first
one in the list is used.
Corresponds to the JSON property protectedEndpoints
1859 1860 1861 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1859 def protected_endpoints @protected_endpoints end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1866 1867 1868 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1866 def update!(**args) @protected_endpoints = args[:protected_endpoints] if args.key?(:protected_endpoints) end |