Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponse
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Secret key is used only in legacy reCAPTCHA. It must be used in a 3rd party integration with legacy reCAPTCHA.
Instance Attribute Summary collapse
-
#legacy_secret_key ⇒ String
The secret key (also known as shared secret) authorizes communication between your application backend and the reCAPTCHA Enterprise server to create an assessment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponse
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponse
Returns a new instance of GoogleCloudRecaptchaenterpriseV1RetrieveLegacySecretKeyResponse.
2006 2007 2008 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#legacy_secret_key ⇒ String
The secret key (also known as shared secret) authorizes communication between
your application backend and the reCAPTCHA Enterprise server to create an
assessment. The secret key needs to be kept safe for security purposes.
Corresponds to the JSON property legacySecretKey
2004 2005 2006 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2004 def legacy_secret_key @legacy_secret_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2011 2012 2013 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2011 def update!(**args) @legacy_secret_key = args[:legacy_secret_key] if args.key?(:legacy_secret_key) end |