Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1RiskAnalysis

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Risk analysis result for an event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1RiskAnalysis

Returns a new instance of GoogleCloudRecaptchaenterpriseV1RiskAnalysis.



2057
2058
2059
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2057

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#challengeString

Output only. Challenge information for Universal, POLICY_BASED_CHALLENGE and INVISIBLE keys. Corresponds to the JSON property challenge

Returns:

  • (String)


2024
2025
2026
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2024

def challenge
  @challenge
end

#extended_verdict_reasonsArray<String>

Output only. Additional reasons contributing to the risk analysis verdict. These reasons are available to Enterprise tier projects only. Contact sales for more information. The set of reasons is subject to change. Corresponds to the JSON property extendedVerdictReasons

Returns:

  • (Array<String>)


2031
2032
2033
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2031

def extended_verdict_reasons
  @extended_verdict_reasons
end

#last_challenge_typeString

Output only. Type of the last challenge presented to the user for Universal, POLICY_BASED_CHALLENGE and INVISIBLE keys. The field is only set when a challenge was presented to the user. Corresponds to the JSON property lastChallengeType

Returns:

  • (String)


2038
2039
2040
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2038

def last_challenge_type
  @last_challenge_type
end

#reasonsArray<String>

Output only. Reasons contributing to the risk analysis verdict. Corresponds to the JSON property reasons

Returns:

  • (Array<String>)


2043
2044
2045
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2043

def reasons
  @reasons
end

#scoreFloat

Output only. Legitimate event score from 0.0 to 1.0. (1.0 means very likely legitimate traffic while 0.0 means very likely non-legitimate traffic). Corresponds to the JSON property score

Returns:

  • (Float)


2049
2050
2051
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2049

def score
  @score
end

#verified_botsArray<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Bot>

Output only. Bots with identities that have been verified by reCAPTCHA and detected in the event. Corresponds to the JSON property verifiedBots



2055
2056
2057
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2055

def verified_bots
  @verified_bots
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2062
2063
2064
2065
2066
2067
2068
2069
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2062

def update!(**args)
  @challenge = args[:challenge] if args.key?(:challenge)
  @extended_verdict_reasons = args[:extended_verdict_reasons] if args.key?(:extended_verdict_reasons)
  @last_challenge_type = args[:last_challenge_type] if args.key?(:last_challenge_type)
  @reasons = args[:reasons] if args.key?(:reasons)
  @score = args[:score] if args.key?(:score)
  @verified_bots = args[:verified_bots] if args.key?(:verified_bots)
end