Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1RiskAnalysis

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Risk analysis result for an event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1RiskAnalysis

Returns a new instance of GoogleCloudRecaptchaenterpriseV1RiskAnalysis.



1771
1772
1773
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#challengeString

Output only. Challenge information for POLICY_BASED_CHALLENGE and INVISIBLE keys. Corresponds to the JSON property challenge

Returns:

  • (String)


1745
1746
1747
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1745

def challenge
  @challenge
end

#extended_verdict_reasonsArray<String>

Output only. Additional reasons contributing to the risk analysis verdict. These reasons are available to Enterprise tier projects only. Contact sales for more information. The set of reasons is subject to change. Corresponds to the JSON property extendedVerdictReasons

Returns:

  • (Array<String>)


1752
1753
1754
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1752

def extended_verdict_reasons
  @extended_verdict_reasons
end

#reasonsArray<String>

Output only. Reasons contributing to the risk analysis verdict. Corresponds to the JSON property reasons

Returns:

  • (Array<String>)


1757
1758
1759
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1757

def reasons
  @reasons
end

#scoreFloat

Output only. Legitimate event score from 0.0 to 1.0. (1.0 means very likely legitimate traffic while 0.0 means very likely non-legitimate traffic). Corresponds to the JSON property score

Returns:

  • (Float)


1763
1764
1765
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1763

def score
  @score
end

#verified_botsArray<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Bot>

Output only. Bots with identities that have been verified by reCAPTCHA and detected in the event. Corresponds to the JSON property verifiedBots



1769
1770
1771
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1769

def verified_bots
  @verified_bots
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1776
1777
1778
1779
1780
1781
1782
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1776

def update!(**args)
  @challenge = args[:challenge] if args.key?(:challenge)
  @extended_verdict_reasons = args[:extended_verdict_reasons] if args.key?(:extended_verdict_reasons)
  @reasons = args[:reasons] if args.key?(:reasons)
  @score = args[:score] if args.key?(:score)
  @verified_bots = args[:verified_bots] if args.key?(:verified_bots)
end