Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1RiskAnalysis

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Risk analysis result for an event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1RiskAnalysis

Returns a new instance of GoogleCloudRecaptchaenterpriseV1RiskAnalysis.



1685
1686
1687
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#challengeString

Output only. Challenge information for POLICY_BASED_CHALLENGE and INVISIBLE keys. Corresponds to the JSON property challenge

Returns:

  • (String)


1660
1661
1662
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1660

def challenge
  @challenge
end

#extended_verdict_reasonsArray<String>

Output only. Extended verdict reasons to be used for experimentation only. The set of possible reasons is subject to change. Corresponds to the JSON property extendedVerdictReasons

Returns:

  • (Array<String>)


1666
1667
1668
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1666

def extended_verdict_reasons
  @extended_verdict_reasons
end

#reasonsArray<String>

Output only. Reasons contributing to the risk analysis verdict. Corresponds to the JSON property reasons

Returns:

  • (Array<String>)


1671
1672
1673
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1671

def reasons
  @reasons
end

#scoreFloat

Output only. Legitimate event score from 0.0 to 1.0. (1.0 means very likely legitimate traffic while 0.0 means very likely non-legitimate traffic). Corresponds to the JSON property score

Returns:

  • (Float)


1677
1678
1679
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1677

def score
  @score
end

#verified_botsArray<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1Bot>

Output only. Bots with identities that have been verified by reCAPTCHA and detected in the event. Corresponds to the JSON property verifiedBots



1683
1684
1685
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1683

def verified_bots
  @verified_bots
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1690
1691
1692
1693
1694
1695
1696
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1690

def update!(**args)
  @challenge = args[:challenge] if args.key?(:challenge)
  @extended_verdict_reasons = args[:extended_verdict_reasons] if args.key?(:extended_verdict_reasons)
  @reasons = args[:reasons] if args.key?(:reasons)
  @score = args[:score] if args.key?(:score)
  @verified_bots = args[:verified_bots] if args.key?(:verified_bots)
end