Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsRequest
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
The request message to search related account group memberships.
Instance Attribute Summary collapse
-
#account_id ⇒ String
Optional.
-
#hashed_account_id ⇒ String
Optional.
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsRequest
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsRequest
Returns a new instance of GoogleCloudRecaptchaenterpriseV1SearchRelatedAccountGroupMembershipsRequest.
1870 1871 1872 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1870 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
Optional. The unique stable account identifier used to search connections. The
identifier should correspond to an account_id provided in a previous
CreateAssessment or AnnotateAssessment call. Either hashed_account_id or
account_id must be set, but not both.
Corresponds to the JSON property accountId
1842 1843 1844 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1842 def account_id @account_id end |
#hashed_account_id ⇒ String
Optional. Deprecated: use account_id instead. The unique stable hashed
account identifier used to search connections. The identifier should
correspond to a hashed_account_id provided in a previous CreateAssessment
or AnnotateAssessment call. Either hashed_account_id or account_id must be
set, but not both.
Corresponds to the JSON property hashedAccountId
NOTE: Values are automatically base64 encoded/decoded in the client library.
1852 1853 1854 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1852 def hashed_account_id @hashed_account_id end |
#page_size ⇒ Fixnum
Optional. The maximum number of groups to return. The service might return
fewer than this value. If unspecified, at most 50 groups are returned. The
maximum value is 1000; values above 1000 are coerced to 1000.
Corresponds to the JSON property pageSize
1859 1860 1861 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1859 def page_size @page_size end |
#page_token ⇒ String
Optional. A page token, received from a previous
SearchRelatedAccountGroupMemberships call. Provide this to retrieve the
subsequent page. When paginating, all other parameters provided to
SearchRelatedAccountGroupMemberships must match the call that provided the
page token.
Corresponds to the JSON property pageToken
1868 1869 1870 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1868 def page_token @page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1875 1876 1877 1878 1879 1880 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1875 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @hashed_account_id = args[:hashed_account_id] if args.key?(:hashed_account_id) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) end |