Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TokenProperties
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TokenProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Properties of the provided event token.
Instance Attribute Summary collapse
-
#action ⇒ String
Output only.
-
#android_package_name ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#hostname ⇒ String
Output only.
-
#invalid_reason ⇒ String
Output only.
-
#ios_bundle_id ⇒ String
Output only.
-
#valid ⇒ Boolean
(also: #valid?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TokenProperties
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1TokenProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TokenProperties
Returns a new instance of GoogleCloudRecaptchaenterpriseV1TokenProperties.
2298 2299 2300 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Output only. Action name provided at token generation.
Corresponds to the JSON property action
2260 2261 2262 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2260 def action @action end |
#android_package_name ⇒ String
Output only. The name of the Android package with which the token was
generated (Android keys only).
Corresponds to the JSON property androidPackageName
2266 2267 2268 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2266 def android_package_name @android_package_name end |
#create_time ⇒ String
Output only. The timestamp corresponding to the generation of the token.
Corresponds to the JSON property createTime
2271 2272 2273 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2271 def create_time @create_time end |
#hostname ⇒ String
Output only. The hostname of the page on which the token was generated (Web
keys only).
Corresponds to the JSON property hostname
2277 2278 2279 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2277 def hostname @hostname end |
#invalid_reason ⇒ String
Output only. Reason associated with the response when valid = false.
Corresponds to the JSON property invalidReason
2282 2283 2284 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2282 def invalid_reason @invalid_reason end |
#ios_bundle_id ⇒ String
Output only. The ID of the iOS bundle with which the token was generated (iOS
keys only).
Corresponds to the JSON property iosBundleId
2288 2289 2290 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2288 def ios_bundle_id @ios_bundle_id end |
#valid ⇒ Boolean Also known as: valid?
Output only. Indicates whether the provided user response token is valid. If
false, the token is invalid, either because the user failed the challenge or
for a reason provided in the invalid_reason field.
Corresponds to the JSON property valid
2295 2296 2297 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2295 def valid @valid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2303 2304 2305 2306 2307 2308 2309 2310 2311 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2303 def update!(**args) @action = args[:action] if args.key?(:action) @android_package_name = args[:android_package_name] if args.key?(:android_package_name) @create_time = args[:create_time] if args.key?(:create_time) @hostname = args[:hostname] if args.key?(:hostname) @invalid_reason = args[:invalid_reason] if args.key?(:invalid_reason) @ios_bundle_id = args[:ios_bundle_id] if args.key?(:ios_bundle_id) @valid = args[:valid] if args.key?(:valid) end |