Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TokenProperties
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TokenProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Properties of the provided event token.
Instance Attribute Summary collapse
-
#action ⇒ String
Output only.
-
#android_package_name ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#hostname ⇒ String
Output only.
-
#invalid_reason ⇒ String
Output only.
-
#ios_bundle_id ⇒ String
Output only.
-
#valid ⇒ Boolean
(also: #valid?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TokenProperties
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1TokenProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TokenProperties
Returns a new instance of GoogleCloudRecaptchaenterpriseV1TokenProperties.
2003 2004 2005 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2003 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Output only. Action name provided at token generation.
Corresponds to the JSON property action
1965 1966 1967 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1965 def action @action end |
#android_package_name ⇒ String
Output only. The name of the Android package with which the token was
generated (Android keys only).
Corresponds to the JSON property androidPackageName
1971 1972 1973 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1971 def android_package_name @android_package_name end |
#create_time ⇒ String
Output only. The timestamp corresponding to the generation of the token.
Corresponds to the JSON property createTime
1976 1977 1978 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1976 def create_time @create_time end |
#hostname ⇒ String
Output only. The hostname of the page on which the token was generated (Web
keys only).
Corresponds to the JSON property hostname
1982 1983 1984 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1982 def hostname @hostname end |
#invalid_reason ⇒ String
Output only. Reason associated with the response when valid = false.
Corresponds to the JSON property invalidReason
1987 1988 1989 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1987 def invalid_reason @invalid_reason end |
#ios_bundle_id ⇒ String
Output only. The ID of the iOS bundle with which the token was generated (iOS
keys only).
Corresponds to the JSON property iosBundleId
1993 1994 1995 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1993 def ios_bundle_id @ios_bundle_id end |
#valid ⇒ Boolean Also known as: valid?
Output only. Indicates whether the provided user response token is valid. If
false, the token is invalid, either because the user failed the challenge or
for a reason provided in the invalid_reason field.
Corresponds to the JSON property valid
2000 2001 2002 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2000 def valid @valid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2008 2009 2010 2011 2012 2013 2014 2015 2016 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2008 def update!(**args) @action = args[:action] if args.key?(:action) @android_package_name = args[:android_package_name] if args.key?(:android_package_name) @create_time = args[:create_time] if args.key?(:create_time) @hostname = args[:hostname] if args.key?(:hostname) @invalid_reason = args[:invalid_reason] if args.key?(:invalid_reason) @ios_bundle_id = args[:ios_bundle_id] if args.key?(:ios_bundle_id) @valid = args[:valid] if args.key?(:valid) end |