Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Transaction data associated with a payment protected by reCAPTCHA Enterprise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TransactionData

Returns a new instance of GoogleCloudRecaptchaenterpriseV1TransactionData.



2096
2097
2098
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billing_addressGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress

Structured address format for billing and shipping addresses. Corresponds to the JSON property billingAddress



2026
2027
2028
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2026

def billing_address
  @billing_address
end

#card_binString

Optional. The Bank Identification Number - generally the first 6 or 8 digits of the card. Corresponds to the JSON property cardBin

Returns:

  • (String)


2032
2033
2034
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2032

def card_bin
  @card_bin
end

#card_last_fourString

Optional. The last four digits of the card. Corresponds to the JSON property cardLastFour

Returns:

  • (String)


2037
2038
2039
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2037

def card_last_four
  @card_last_four
end

#currency_codeString

Optional. The currency code in ISO-4217 format. Corresponds to the JSON property currencyCode

Returns:

  • (String)


2042
2043
2044
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2042

def currency_code
  @currency_code
end

#gateway_infoGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataGatewayInfo

Details about the transaction from the gateway. Corresponds to the JSON property gatewayInfo



2047
2048
2049
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2047

def gateway_info
  @gateway_info
end

#itemsArray<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataItem>

Optional. Items purchased in this transaction. Corresponds to the JSON property items



2052
2053
2054
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2052

def items
  @items
end

#merchantsArray<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataUser>

Optional. Information about the user or users fulfilling the transaction. Corresponds to the JSON property merchants



2057
2058
2059
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2057

def merchants
  @merchants
end

#payment_methodString

Optional. The payment method for the transaction. The allowed values are: * credit-card * debit-card * gift-card * processor-name (If a third-party is used, for example, processor-paypal) * custom-name (If an alternative method is used, for example, custom-crypto) Corresponds to the JSON property paymentMethod

Returns:

  • (String)


2065
2066
2067
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2065

def payment_method
  @payment_method
end

#shipping_addressGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress

Structured address format for billing and shipping addresses. Corresponds to the JSON property shippingAddress



2070
2071
2072
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2070

def shipping_address
  @shipping_address
end

#shipping_valueFloat

Optional. The value of shipping in the specified currency. 0 for free or no shipping. Corresponds to the JSON property shippingValue

Returns:

  • (Float)


2076
2077
2078
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2076

def shipping_value
  @shipping_value
end

#transaction_idString

Unique identifier for the transaction. This custom identifier can be used to reference this transaction in the future, for example, labeling a refund or chargeback event. Two attempts at the same transaction should use the same transaction id. Corresponds to the JSON property transactionId

Returns:

  • (String)


2084
2085
2086
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2084

def transaction_id
  @transaction_id
end

#userGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataUser

Details about a user's account involved in the transaction. Corresponds to the JSON property user



2089
2090
2091
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2089

def user
  @user
end

#valueFloat

Optional. The decimal value of the transaction in the specified currency. Corresponds to the JSON property value

Returns:

  • (Float)


2094
2095
2096
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2094

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2101

def update!(**args)
  @billing_address = args[:billing_address] if args.key?(:billing_address)
  @card_bin = args[:card_bin] if args.key?(:card_bin)
  @card_last_four = args[:card_last_four] if args.key?(:card_last_four)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @gateway_info = args[:gateway_info] if args.key?(:gateway_info)
  @items = args[:items] if args.key?(:items)
  @merchants = args[:merchants] if args.key?(:merchants)
  @payment_method = args[:payment_method] if args.key?(:payment_method)
  @shipping_address = args[:shipping_address] if args.key?(:shipping_address)
  @shipping_value = args[:shipping_value] if args.key?(:shipping_value)
  @transaction_id = args[:transaction_id] if args.key?(:transaction_id)
  @user = args[:user] if args.key?(:user)
  @value = args[:value] if args.key?(:value)
end