Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionData
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Transaction data associated with a payment protected by reCAPTCHA Enterprise.
Instance Attribute Summary collapse
-
#billing_address ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
Structured address format for billing and shipping addresses.
-
#card_bin ⇒ String
Optional.
-
#card_last_four ⇒ String
Optional.
-
#currency_code ⇒ String
Optional.
-
#gateway_info ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataGatewayInfo
Details about the transaction from the gateway.
-
#items ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataItem>
Optional.
-
#merchants ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataUser>
Optional.
-
#payment_method ⇒ String
Optional.
-
#shipping_address ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
Structured address format for billing and shipping addresses.
-
#shipping_value ⇒ Float
Optional.
-
#transaction_id ⇒ String
Unique identifier for the transaction.
-
#user ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataUser
Details about a user's account involved in the transaction.
-
#value ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TransactionData
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1TransactionData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TransactionData
Returns a new instance of GoogleCloudRecaptchaenterpriseV1TransactionData.
2098 2099 2100 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2098 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billing_address ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
Structured address format for billing and shipping addresses.
Corresponds to the JSON property billingAddress
2028 2029 2030 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2028 def billing_address @billing_address end |
#card_bin ⇒ String
Optional. The Bank Identification Number - generally the first 6 or 8 digits
of the card.
Corresponds to the JSON property cardBin
2034 2035 2036 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2034 def card_bin @card_bin end |
#card_last_four ⇒ String
Optional. The last four digits of the card.
Corresponds to the JSON property cardLastFour
2039 2040 2041 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2039 def card_last_four @card_last_four end |
#currency_code ⇒ String
Optional. The currency code in ISO-4217 format.
Corresponds to the JSON property currencyCode
2044 2045 2046 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2044 def currency_code @currency_code end |
#gateway_info ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataGatewayInfo
Details about the transaction from the gateway.
Corresponds to the JSON property gatewayInfo
2049 2050 2051 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2049 def gateway_info @gateway_info end |
#items ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataItem>
Optional. Items purchased in this transaction.
Corresponds to the JSON property items
2054 2055 2056 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2054 def items @items end |
#merchants ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataUser>
Optional. Information about the user or users fulfilling the transaction.
Corresponds to the JSON property merchants
2059 2060 2061 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2059 def merchants @merchants end |
#payment_method ⇒ String
Optional. The payment method for the transaction. The allowed values are: *
credit-card * debit-card * gift-card * processor-name (If a third-party is
used, for example, processor-paypal) * custom-name (If an alternative method
is used, for example, custom-crypto)
Corresponds to the JSON property paymentMethod
2067 2068 2069 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2067 def payment_method @payment_method end |
#shipping_address ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
Structured address format for billing and shipping addresses.
Corresponds to the JSON property shippingAddress
2072 2073 2074 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2072 def shipping_address @shipping_address end |
#shipping_value ⇒ Float
Optional. The value of shipping in the specified currency. 0 for free or no
shipping.
Corresponds to the JSON property shippingValue
2078 2079 2080 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2078 def shipping_value @shipping_value end |
#transaction_id ⇒ String
Unique identifier for the transaction. This custom identifier can be used to
reference this transaction in the future, for example, labeling a refund or
chargeback event. Two attempts at the same transaction should use the same
transaction id.
Corresponds to the JSON property transactionId
2086 2087 2088 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2086 def transaction_id @transaction_id end |
#user ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataUser
Details about a user's account involved in the transaction.
Corresponds to the JSON property user
2091 2092 2093 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2091 def user @user end |
#value ⇒ Float
Optional. The decimal value of the transaction in the specified currency.
Corresponds to the JSON property value
2096 2097 2098 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2096 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2103 def update!(**args) @billing_address = args[:billing_address] if args.key?(:billing_address) @card_bin = args[:card_bin] if args.key?(:card_bin) @card_last_four = args[:card_last_four] if args.key?(:card_last_four) @currency_code = args[:currency_code] if args.key?(:currency_code) @gateway_info = args[:gateway_info] if args.key?(:gateway_info) @items = args[:items] if args.key?(:items) @merchants = args[:merchants] if args.key?(:merchants) @payment_method = args[:payment_method] if args.key?(:payment_method) @shipping_address = args[:shipping_address] if args.key?(:shipping_address) @shipping_value = args[:shipping_value] if args.key?(:shipping_value) @transaction_id = args[:transaction_id] if args.key?(:transaction_id) @user = args[:user] if args.key?(:user) @value = args[:value] if args.key?(:value) end |