Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionData
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Transaction data associated with a payment protected by reCAPTCHA Enterprise.
Instance Attribute Summary collapse
-
#billing_address ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
Structured address format for billing and shipping addresses.
-
#card_bin ⇒ String
Optional.
-
#card_last_four ⇒ String
Optional.
-
#currency_code ⇒ String
Optional.
-
#gateway_info ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataGatewayInfo
Details about the transaction from the gateway.
-
#items ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataItem>
Optional.
-
#merchants ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataUser>
Optional.
-
#payment_method ⇒ String
Optional.
-
#shipping_address ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
Structured address format for billing and shipping addresses.
-
#shipping_value ⇒ Float
Optional.
-
#transaction_id ⇒ String
Unique identifier for the transaction.
-
#user ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataUser
Details about a user's account involved in the transaction.
-
#value ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TransactionData
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1TransactionData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TransactionData
Returns a new instance of GoogleCloudRecaptchaenterpriseV1TransactionData.
2017 2018 2019 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billing_address ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
Structured address format for billing and shipping addresses.
Corresponds to the JSON property billingAddress
1947 1948 1949 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1947 def billing_address @billing_address end |
#card_bin ⇒ String
Optional. The Bank Identification Number - generally the first 6 or 8 digits
of the card.
Corresponds to the JSON property cardBin
1953 1954 1955 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1953 def card_bin @card_bin end |
#card_last_four ⇒ String
Optional. The last four digits of the card.
Corresponds to the JSON property cardLastFour
1958 1959 1960 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1958 def card_last_four @card_last_four end |
#currency_code ⇒ String
Optional. The currency code in ISO-4217 format.
Corresponds to the JSON property currencyCode
1963 1964 1965 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1963 def currency_code @currency_code end |
#gateway_info ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataGatewayInfo
Details about the transaction from the gateway.
Corresponds to the JSON property gatewayInfo
1968 1969 1970 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1968 def gateway_info @gateway_info end |
#items ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataItem>
Optional. Items purchased in this transaction.
Corresponds to the JSON property items
1973 1974 1975 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1973 def items @items end |
#merchants ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataUser>
Optional. Information about the user or users fulfilling the transaction.
Corresponds to the JSON property merchants
1978 1979 1980 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1978 def merchants @merchants end |
#payment_method ⇒ String
Optional. The payment method for the transaction. The allowed values are: *
credit-card * debit-card * gift-card * processor-name (If a third-party is
used, for example, processor-paypal) * custom-name (If an alternative method
is used, for example, custom-crypto)
Corresponds to the JSON property paymentMethod
1986 1987 1988 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1986 def payment_method @payment_method end |
#shipping_address ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
Structured address format for billing and shipping addresses.
Corresponds to the JSON property shippingAddress
1991 1992 1993 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1991 def shipping_address @shipping_address end |
#shipping_value ⇒ Float
Optional. The value of shipping in the specified currency. 0 for free or no
shipping.
Corresponds to the JSON property shippingValue
1997 1998 1999 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 1997 def shipping_value @shipping_value end |
#transaction_id ⇒ String
Unique identifier for the transaction. This custom identifier can be used to
reference this transaction in the future, for example, labeling a refund or
chargeback event. Two attempts at the same transaction should use the same
transaction id.
Corresponds to the JSON property transactionId
2005 2006 2007 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2005 def transaction_id @transaction_id end |
#user ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataUser
Details about a user's account involved in the transaction.
Corresponds to the JSON property user
2010 2011 2012 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2010 def user @user end |
#value ⇒ Float
Optional. The decimal value of the transaction in the specified currency.
Corresponds to the JSON property value
2015 2016 2017 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2015 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2022 def update!(**args) @billing_address = args[:billing_address] if args.key?(:billing_address) @card_bin = args[:card_bin] if args.key?(:card_bin) @card_last_four = args[:card_last_four] if args.key?(:card_last_four) @currency_code = args[:currency_code] if args.key?(:currency_code) @gateway_info = args[:gateway_info] if args.key?(:gateway_info) @items = args[:items] if args.key?(:items) @merchants = args[:merchants] if args.key?(:merchants) @payment_method = args[:payment_method] if args.key?(:payment_method) @shipping_address = args[:shipping_address] if args.key?(:shipping_address) @shipping_value = args[:shipping_value] if args.key?(:shipping_value) @transaction_id = args[:transaction_id] if args.key?(:transaction_id) @user = args[:user] if args.key?(:user) @value = args[:value] if args.key?(:value) end |