Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Structured address format for billing and shipping addresses.
Instance Attribute Summary collapse
-
#address ⇒ Array<String>
Optional.
-
#administrative_area ⇒ String
Optional.
-
#locality ⇒ String
Optional.
-
#postal_code ⇒ String
Optional.
-
#recipient ⇒ String
Optional.
-
#region_code ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1TransactionDataAddress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
Returns a new instance of GoogleCloudRecaptchaenterpriseV1TransactionDataAddress.
2450 2451 2452 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2450 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ Array<String>
Optional. The first lines of the address. The first line generally contains
the street name and number, and further lines may include information such as
an apartment number.
Corresponds to the JSON property address
2422 2423 2424 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2422 def address @address end |
#administrative_area ⇒ String
Optional. The state, province, or otherwise administrative area of the address.
Corresponds to the JSON property administrativeArea
2427 2428 2429 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2427 def administrative_area @administrative_area end |
#locality ⇒ String
Optional. The town/city of the address.
Corresponds to the JSON property locality
2432 2433 2434 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2432 def locality @locality end |
#postal_code ⇒ String
Optional. The postal or ZIP code of the address.
Corresponds to the JSON property postalCode
2437 2438 2439 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2437 def postal_code @postal_code end |
#recipient ⇒ String
Optional. The recipient name, potentially including information such as "care
of".
Corresponds to the JSON property recipient
2443 2444 2445 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2443 def recipient @recipient end |
#region_code ⇒ String
Optional. The CLDR country/region of the address.
Corresponds to the JSON property regionCode
2448 2449 2450 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2448 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2455 def update!(**args) @address = args[:address] if args.key?(:address) @administrative_area = args[:administrative_area] if args.key?(:administrative_area) @locality = args[:locality] if args.key?(:locality) @postal_code = args[:postal_code] if args.key?(:postal_code) @recipient = args[:recipient] if args.key?(:recipient) @region_code = args[:region_code] if args.key?(:region_code) end |