Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Structured address format for billing and shipping addresses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TransactionDataAddress

Returns a new instance of GoogleCloudRecaptchaenterpriseV1TransactionDataAddress.



2447
2448
2449
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressArray<String>

Optional. The first lines of the address. The first line generally contains the street name and number, and further lines may include information such as an apartment number. Corresponds to the JSON property address

Returns:

  • (Array<String>)


2419
2420
2421
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2419

def address
  @address
end

#administrative_areaString

Optional. The state, province, or otherwise administrative area of the address. Corresponds to the JSON property administrativeArea

Returns:

  • (String)


2424
2425
2426
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2424

def administrative_area
  @administrative_area
end

#localityString

Optional. The town/city of the address. Corresponds to the JSON property locality

Returns:

  • (String)


2429
2430
2431
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2429

def locality
  @locality
end

#postal_codeString

Optional. The postal or ZIP code of the address. Corresponds to the JSON property postalCode

Returns:

  • (String)


2434
2435
2436
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2434

def postal_code
  @postal_code
end

#recipientString

Optional. The recipient name, potentially including information such as "care of". Corresponds to the JSON property recipient

Returns:

  • (String)


2440
2441
2442
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2440

def recipient
  @recipient
end

#region_codeString

Optional. The CLDR country/region of the address. Corresponds to the JSON property regionCode

Returns:

  • (String)


2445
2446
2447
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2445

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2452
2453
2454
2455
2456
2457
2458
2459
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2452

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @administrative_area = args[:administrative_area] if args.key?(:administrative_area)
  @locality = args[:locality] if args.key?(:locality)
  @postal_code = args[:postal_code] if args.key?(:postal_code)
  @recipient = args[:recipient] if args.key?(:recipient)
  @region_code = args[:region_code] if args.key?(:region_code)
end