Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Structured address format for billing and shipping addresses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TransactionDataAddress

Returns a new instance of GoogleCloudRecaptchaenterpriseV1TransactionDataAddress.



2155
2156
2157
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2155

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressArray<String>

Optional. The first lines of the address. The first line generally contains the street name and number, and further lines may include information such as an apartment number. Corresponds to the JSON property address

Returns:

  • (Array<String>)


2127
2128
2129
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2127

def address
  @address
end

#administrative_areaString

Optional. The state, province, or otherwise administrative area of the address. Corresponds to the JSON property administrativeArea

Returns:

  • (String)


2132
2133
2134
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2132

def administrative_area
  @administrative_area
end

#localityString

Optional. The town/city of the address. Corresponds to the JSON property locality

Returns:

  • (String)


2137
2138
2139
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2137

def locality
  @locality
end

#postal_codeString

Optional. The postal or ZIP code of the address. Corresponds to the JSON property postalCode

Returns:

  • (String)


2142
2143
2144
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2142

def postal_code
  @postal_code
end

#recipientString

Optional. The recipient name, potentially including information such as "care of". Corresponds to the JSON property recipient

Returns:

  • (String)


2148
2149
2150
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2148

def recipient
  @recipient
end

#region_codeString

Optional. The CLDR country/region of the address. Corresponds to the JSON property regionCode

Returns:

  • (String)


2153
2154
2155
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2153

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2160
2161
2162
2163
2164
2165
2166
2167
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2160

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @administrative_area = args[:administrative_area] if args.key?(:administrative_area)
  @locality = args[:locality] if args.key?(:locality)
  @postal_code = args[:postal_code] if args.key?(:postal_code)
  @recipient = args[:recipient] if args.key?(:recipient)
  @region_code = args[:region_code] if args.key?(:region_code)
end