Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Structured address format for billing and shipping addresses.
Instance Attribute Summary collapse
-
#address ⇒ Array<String>
Optional.
-
#administrative_area ⇒ String
Optional.
-
#locality ⇒ String
Optional.
-
#postal_code ⇒ String
Optional.
-
#recipient ⇒ String
Optional.
-
#region_code ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1TransactionDataAddress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TransactionDataAddress
Returns a new instance of GoogleCloudRecaptchaenterpriseV1TransactionDataAddress.
2157 2158 2159 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2157 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ Array<String>
Optional. The first lines of the address. The first line generally contains
the street name and number, and further lines may include information such as
an apartment number.
Corresponds to the JSON property address
2129 2130 2131 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2129 def address @address end |
#administrative_area ⇒ String
Optional. The state, province, or otherwise administrative area of the address.
Corresponds to the JSON property administrativeArea
2134 2135 2136 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2134 def administrative_area @administrative_area end |
#locality ⇒ String
Optional. The town/city of the address.
Corresponds to the JSON property locality
2139 2140 2141 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2139 def locality @locality end |
#postal_code ⇒ String
Optional. The postal or ZIP code of the address.
Corresponds to the JSON property postalCode
2144 2145 2146 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2144 def postal_code @postal_code end |
#recipient ⇒ String
Optional. The recipient name, potentially including information such as "care
of".
Corresponds to the JSON property recipient
2150 2151 2152 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2150 def recipient @recipient end |
#region_code ⇒ String
Optional. The CLDR country/region of the address.
Corresponds to the JSON property regionCode
2155 2156 2157 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2155 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2162 2163 2164 2165 2166 2167 2168 2169 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2162 def update!(**args) @address = args[:address] if args.key?(:address) @administrative_area = args[:administrative_area] if args.key?(:administrative_area) @locality = args[:locality] if args.key?(:locality) @postal_code = args[:postal_code] if args.key?(:postal_code) @recipient = args[:recipient] if args.key?(:recipient) @region_code = args[:region_code] if args.key?(:region_code) end |