Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1TransactionDataAddress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Structured address format for billing and shipping addresses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1TransactionDataAddress

Returns a new instance of GoogleCloudRecaptchaenterpriseV1TransactionDataAddress.



2076
2077
2078
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2076

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressArray<String>

Optional. The first lines of the address. The first line generally contains the street name and number, and further lines may include information such as an apartment number. Corresponds to the JSON property address

Returns:

  • (Array<String>)


2048
2049
2050
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2048

def address
  @address
end

#administrative_areaString

Optional. The state, province, or otherwise administrative area of the address. Corresponds to the JSON property administrativeArea

Returns:

  • (String)


2053
2054
2055
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2053

def administrative_area
  @administrative_area
end

#localityString

Optional. The town/city of the address. Corresponds to the JSON property locality

Returns:

  • (String)


2058
2059
2060
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2058

def locality
  @locality
end

#postal_codeString

Optional. The postal or ZIP code of the address. Corresponds to the JSON property postalCode

Returns:

  • (String)


2063
2064
2065
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2063

def postal_code
  @postal_code
end

#recipientString

Optional. The recipient name, potentially including information such as "care of". Corresponds to the JSON property recipient

Returns:

  • (String)


2069
2070
2071
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2069

def recipient
  @recipient
end

#region_codeString

Optional. The CLDR country/region of the address. Corresponds to the JSON property regionCode

Returns:

  • (String)


2074
2075
2076
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2074

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2081
2082
2083
2084
2085
2086
2087
2088
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2081

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @administrative_area = args[:administrative_area] if args.key?(:administrative_area)
  @locality = args[:locality] if args.key?(:locality)
  @postal_code = args[:postal_code] if args.key?(:postal_code)
  @recipient = args[:recipient] if args.key?(:recipient)
  @region_code = args[:region_code] if args.key?(:region_code)
end