Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1UserInfo
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1UserInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
User information associated with a request protected by reCAPTCHA Enterprise.
Instance Attribute Summary collapse
-
#account_id ⇒ String
Optional.
-
#create_account_time ⇒ String
Optional.
-
#user_ids ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1UserId>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1UserInfo
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1UserInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1UserInfo
Returns a new instance of GoogleCloudRecaptchaenterpriseV1UserInfo.
2403 2404 2405 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2403 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
Optional. For logged-in requests or login/registration requests, the unique
account identifier associated with this user. You can use the username if it
is stable (meaning it is the same for every request associated with the same
user), or any stable user ID of your choice. Leave blank for non logged-in
actions or guest checkout.
Corresponds to the JSON property accountId
2389 2390 2391 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2389 def account_id @account_id end |
#create_account_time ⇒ String
Optional. Creation time for this account associated with this user. Leave
blank for non logged-in actions, guest checkout, or when there is no account
associated with the current user.
Corresponds to the JSON property createAccountTime
2396 2397 2398 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2396 def create_account_time @create_account_time end |
#user_ids ⇒ Array<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1UserId>
Optional. Identifiers associated with this user or request.
Corresponds to the JSON property userIds
2401 2402 2403 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2401 def user_ids @user_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2408 2409 2410 2411 2412 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2408 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @create_account_time = args[:create_account_time] if args.key?(:create_account_time) @user_ids = args[:user_ids] if args.key?(:user_ids) end |