Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1UserInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

User information associated with a request protected by reCAPTCHA Enterprise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1UserInfo

Returns a new instance of GoogleCloudRecaptchaenterpriseV1UserInfo.



2324
2325
2326
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

Optional. For logged-in requests or login/registration requests, the unique account identifier associated with this user. You can use the username if it is stable (meaning it is the same for every request associated with the same user), or any stable user ID of your choice. Leave blank for non logged-in actions or guest checkout. Corresponds to the JSON property accountId

Returns:

  • (String)


2310
2311
2312
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2310

def 
  @account_id
end

#create_account_timeString

Optional. Creation time for this account associated with this user. Leave blank for non logged-in actions, guest checkout, or when there is no account associated with the current user. Corresponds to the JSON property createAccountTime

Returns:

  • (String)


2317
2318
2319
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2317

def 
  @create_account_time
end

#user_idsArray<Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1UserId>

Optional. Identifiers associated with this user or request. Corresponds to the JSON property userIds



2322
2323
2324
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2322

def user_ids
  @user_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2329
2330
2331
2332
2333
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2329

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @create_account_time = args[:create_account_time] if args.key?(:create_account_time)
  @user_ids = args[:user_ids] if args.key?(:user_ids)
end