Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettings
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Settings specific to keys that can be used by websites.
Instance Attribute Summary collapse
-
#allow_all_domains ⇒ Boolean
(also: #allow_all_domains?)
Optional.
-
#allow_amp_traffic ⇒ Boolean
(also: #allow_amp_traffic?)
Optional.
-
#allowed_domains ⇒ Array<String>
Optional.
-
#challenge_security_preference ⇒ String
Optional.
-
#challenge_settings ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettingsChallengeSettings
Settings for POLICY_BASED_CHALLENGE keys to control when a challenge is triggered.
-
#integration_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1WebKeySettings
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1WebKeySettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1WebKeySettings
Returns a new instance of GoogleCloudRecaptchaenterpriseV1WebKeySettings.
2793 2794 2795 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2793 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_all_domains ⇒ Boolean Also known as: allow_all_domains?
Optional. If set to true, it means allowed_domains are not enforced.
Corresponds to the JSON property allowAllDomains
2753 2754 2755 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2753 def allow_all_domains @allow_all_domains end |
#allow_amp_traffic ⇒ Boolean Also known as: allow_amp_traffic?
Optional. If set to true, the key can be used on AMP (Accelerated Mobile Pages)
websites. This is supported only for the SCORE integration type.
Corresponds to the JSON property allowAmpTraffic
2760 2761 2762 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2760 def allow_amp_traffic @allow_amp_traffic end |
#allowed_domains ⇒ Array<String>
Optional. Domains or subdomains of websites allowed to use the key. All
subdomains of an allowed domain are automatically allowed. A valid domain
requires a host and must not include any path, port, query or fragment.
Examples: 'example.com' or 'subdomain.example.com' Each key supports a maximum
of 250 domains. To use a key on more domains, set allow_all_domains to true.
When this is set, you are responsible for validating the hostname by checking
the token_properties.hostname field in each assessment response against your
list of allowed domains.
Corresponds to the JSON property allowedDomains
2773 2774 2775 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2773 def allowed_domains @allowed_domains end |
#challenge_security_preference ⇒ String
Optional. Settings for the frequency and difficulty at which this key triggers
captcha challenges. This should only be specified for IntegrationType
CHECKBOX, INVISIBLE or POLICY_BASED_CHALLENGE.
Corresponds to the JSON property challengeSecurityPreference
2780 2781 2782 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2780 def challenge_security_preference @challenge_security_preference end |
#challenge_settings ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettingsChallengeSettings
Settings for POLICY_BASED_CHALLENGE keys to control when a challenge is
triggered.
Corresponds to the JSON property challengeSettings
2786 2787 2788 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2786 def challenge_settings @challenge_settings end |
#integration_type ⇒ String
Required. Describes how this key is integrated with the website.
Corresponds to the JSON property integrationType
2791 2792 2793 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2791 def integration_type @integration_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2798 def update!(**args) @allow_all_domains = args[:allow_all_domains] if args.key?(:allow_all_domains) @allow_amp_traffic = args[:allow_amp_traffic] if args.key?(:allow_amp_traffic) @allowed_domains = args[:allowed_domains] if args.key?(:allowed_domains) @challenge_security_preference = args[:challenge_security_preference] if args.key?(:challenge_security_preference) @challenge_settings = args[:challenge_settings] if args.key?(:challenge_settings) @integration_type = args[:integration_type] if args.key?(:integration_type) end |