Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb

Overview

Settings specific to keys that can be used by websites.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1WebKeySettings

Returns a new instance of GoogleCloudRecaptchaenterpriseV1WebKeySettings.



2490
2491
2492
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2490

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_all_domainsBoolean Also known as: allow_all_domains?

Optional. If set to true, it means allowed_domains are not enforced. Corresponds to the JSON property allowAllDomains

Returns:

  • (Boolean)


2450
2451
2452
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2450

def allow_all_domains
  @allow_all_domains
end

#allow_amp_trafficBoolean Also known as: allow_amp_traffic?

Optional. If set to true, the key can be used on AMP (Accelerated Mobile Pages) websites. This is supported only for the SCORE integration type. Corresponds to the JSON property allowAmpTraffic

Returns:

  • (Boolean)


2457
2458
2459
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2457

def allow_amp_traffic
  @allow_amp_traffic
end

#allowed_domainsArray<String>

Optional. Domains or subdomains of websites allowed to use the key. All subdomains of an allowed domain are automatically allowed. A valid domain requires a host and must not include any path, port, query or fragment. Examples: 'example.com' or 'subdomain.example.com' Each key supports a maximum of 250 domains. To use a key on more domains, set allow_all_domains to true. When this is set, you are responsible for validating the hostname by checking the token_properties.hostname field in each assessment response against your list of allowed domains. Corresponds to the JSON property allowedDomains

Returns:

  • (Array<String>)


2470
2471
2472
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2470

def allowed_domains
  @allowed_domains
end

#challenge_security_preferenceString

Optional. Settings for the frequency and difficulty at which this key triggers captcha challenges. This should only be specified for IntegrationType CHECKBOX, INVISIBLE or POLICY_BASED_CHALLENGE. Corresponds to the JSON property challengeSecurityPreference

Returns:

  • (String)


2477
2478
2479
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2477

def challenge_security_preference
  @challenge_security_preference
end

#challenge_settingsGoogle::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettingsChallengeSettings

Settings for POLICY_BASED_CHALLENGE keys to control when a challenge is triggered. Corresponds to the JSON property challengeSettings



2483
2484
2485
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2483

def challenge_settings
  @challenge_settings
end

#integration_typeString

Required. Describes how this key is integrated with the website. Corresponds to the JSON property integrationType

Returns:

  • (String)


2488
2489
2490
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2488

def integration_type
  @integration_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2495
2496
2497
2498
2499
2500
2501
2502
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2495

def update!(**args)
  @allow_all_domains = args[:allow_all_domains] if args.key?(:allow_all_domains)
  @allow_amp_traffic = args[:allow_amp_traffic] if args.key?(:allow_amp_traffic)
  @allowed_domains = args[:allowed_domains] if args.key?(:allowed_domains)
  @challenge_security_preference = args[:challenge_security_preference] if args.key?(:challenge_security_preference)
  @challenge_settings = args[:challenge_settings] if args.key?(:challenge_settings)
  @integration_type = args[:integration_type] if args.key?(:integration_type)
end