Class: Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettingsChallengeSettings
- Inherits:
-
Object
- Object
- Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettingsChallengeSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recaptchaenterprise_v1/classes.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb,
lib/google/apis/recaptchaenterprise_v1/representations.rb
Overview
Settings for POLICY_BASED_CHALLENGE keys to control when a challenge is triggered.
Instance Attribute Summary collapse
-
#action_settings ⇒ Hash<String,Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettingsActionSettings>
Optional.
-
#default_settings ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettingsActionSettings
Per-action challenge settings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1WebKeySettingsChallengeSettings
constructor
A new instance of GoogleCloudRecaptchaenterpriseV1WebKeySettingsChallengeSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecaptchaenterpriseV1WebKeySettingsChallengeSettings
Returns a new instance of GoogleCloudRecaptchaenterpriseV1WebKeySettingsChallengeSettings.
2463 2464 2465 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_settings ⇒ Hash<String,Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettingsActionSettings>
Optional. The action to score threshold map. The action name should be the
same as the action name passed in the data-action attribute (see https://
cloud.google.com/recaptcha/docs/actions-website). Action names are case-
insensitive. There is a maximum of 100 action settings. An action name has a
maximum length of 100.
Corresponds to the JSON property actionSettings
2456 2457 2458 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2456 def action_settings @action_settings end |
#default_settings ⇒ Google::Apis::RecaptchaenterpriseV1::GoogleCloudRecaptchaenterpriseV1WebKeySettingsActionSettings
Per-action challenge settings.
Corresponds to the JSON property defaultSettings
2461 2462 2463 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2461 def default_settings @default_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2468 2469 2470 2471 |
# File 'lib/google/apis/recaptchaenterprise_v1/classes.rb', line 2468 def update!(**args) @action_settings = args[:action_settings] if args.key?(:action_settings) @default_settings = args[:default_settings] if args.key?(:default_settings) end |